// DTC Lookup and Table

// Includes ..................................................................

#include "dtc.h"

// Defines ...................................................................

#define PDTC(val) (val)
#define CDTC(val) (val | 0x4000)
#define BDTC(val) (val | 0x8000)
#define UDTC(val) (val | 0xC000)


// Data Types ................................................................

typedef const struct {
	const unsigned short DTC;
	const char *Description;
} _DTC_INFO;


// DTC Table .................................................................

//					  "123456789012345678901234567890123456789012345678901234567890"
_DTC_INFO StandardDTCs[] = {
	PDTC(0x0000), "Engine Module Reports 'OK'",
#ifndef DEBUG
	PDTC(0x0001), "Fuel Volume Reg. Circuit Open",
	PDTC(0x0002), "Fuel Volume Reg. Circuit Range/Perf.",
	PDTC(0x0003), "Fuel Volume Reg. Circuit Low",
	PDTC(0x0004), "Fuel Volume Reg. Circuit High",
	PDTC(0x0005), "Fuel Shutoff Valve 'A' Circuit Open",
	PDTC(0x0006), "Fuel Shutoff Valve 'A' Circuit Low",
	PDTC(0x0007), "Fuel Shutoff Valve 'A' Circuit High",
	PDTC(0x0008), "Engine Position System Perf. (B1)",
	PDTC(0x0009), "Engine Position System Perf. (B2)",
	PDTC(0x0010), "'A' Camshaft Pos. Actuator Circuit (B1)",
	PDTC(0x0011), "'A' Camshaft Pos. - Timing Over-Adv. (B1)",
	PDTC(0x0012), "'A' Camshaft Pos. - Timing Over-Re. (B1)",
	PDTC(0x0013), "'B' Camshaft Pos. Actuator Circuit (B1)",
	PDTC(0x0014), "'B' Camshaft Pos. - Timing Over-Adv. (B1)",
	PDTC(0x0015), "'B' Camshaft Pos. - Timing Over-Ret. (B1)",
	PDTC(0x0016), "Crankshaft Pos. - Cam. Pos. Correlation (B1-SA)",
	PDTC(0x0017), "Crankshaft Pos. - Cam. Pos. Correlation (B1-SB)",
	PDTC(0x0018), "Crankshaft Pos. - Cam. Pos. Correlation (B2-SA)",
	PDTC(0x0019), "Crankshaft Pos. - Cam. Pos. Correlation (B2-SB)",
	PDTC(0x0020), "'A' Camshaft Pos. Actuator Circuit (B2)",
	PDTC(0x0021), "'A' Camshaft Pos. - Timing Over-Adv. (B2)",
	PDTC(0x0022), "'A' Camshaft Pos. - Timing Over-Ret. (B2)",
	PDTC(0x0023), "'B' Camshaft Pos. Actuator Circuit (B2)",
	PDTC(0x0024), "'B' Camshaft Pos. - Timing Over-Adv. (B2)",
	PDTC(0x0025), "'B' Camshaft Pos. - Timing Over-Ret. (B2)",
	PDTC(0x0026), "Intake Valve Ctrl. Sol. Range/Perf. (B1)",
	PDTC(0x0027), "Exhaust Valve Ctrl. Sol. Range/Perf. (B1)",
	PDTC(0x0028), "Intake Valve Ctrl. Sol. Range/Perf. (B2)",
	PDTC(0x0029), "Exhaust Valve Ctrl. Sol. Range/Perf. (B2)",
	PDTC(0x0030), "HO2S Heater Control Circuit (B1-S1)",
	PDTC(0x0031), "HO2S Heater Control Circuit Low (B1-S1)",
	PDTC(0x0032), "HO2S Heater Control Circuit High (B1-S1)",
	PDTC(0x0033), "Turbo Bypass Valve Control Circuit",
	PDTC(0x0034), "Turbo Bypass Valve Control Circuit Low",
	PDTC(0x0035), "Turbo Bypass Valve Control Circuit High",
	PDTC(0x0036), "HO2S Heater Control Circuit (B1-S2)",
	PDTC(0x0037), "HO2S Heater Control Circuit Low (B1-S2)",
	PDTC(0x0038), "HO2S Heater Control Circuit High (B1-S2)",
	PDTC(0x0039), "Turbo Bypass Valve Ctrl. Circuit Range/Perf.",
	PDTC(0x0040), "O2 Sensor Signals Swapped (B1-S1, B2-B1)",
	PDTC(0x0041), "O2 Sensor Signals Swapped (B1-S2, B2-B2)",
	PDTC(0x0042), "HO2S Heater Control Circuit (B1-S3)",
	PDTC(0x0043), "HO2S Heater Control Circuit Low (B1-S3)",
	PDTC(0x0044), "HO2S Heater Control Circuit High (B1-S3)",
	PDTC(0x0045), "Turbo Boost Ctrl. Sol. Circuit Open",
	PDTC(0x0046), "Turbo Boost Ctrl. Sol. Circuit Range/Perf.",
	PDTC(0x0047), "Turbo Boost Ctrl. Sol. Circuit Low",
	PDTC(0x0048), "Turbo Boost Ctrl. Sol. Circuit High",
	PDTC(0x0049), "Turbo Turbine Overspeed",
	PDTC(0x0050), "HO2S Heater Control Circuit (B2-S1)",
	PDTC(0x0051), "HO2S Heater Control Circuit Low (B2-S1)",
	PDTC(0x0052), "HO2S Heater Control Circuit High (B2-S1)",
	PDTC(0x0053), "HO2S Heater Resistance (B1-S1)",
	PDTC(0x0054), "HO2S Heater Resistance (B1-S2)",
	PDTC(0x0055), "HO2S Heater Resistance (B1-S3)",
	PDTC(0x0056), "HO2S Heater Control Circuit (B1-S2)",
	PDTC(0x0057), "HO2S Heater Control Circuit Low (B1-S2)",
	PDTC(0x0058), "HO2S Heater Control Circuit High (B1-S2)",
	PDTC(0x0059), "HO2S Heater Resistance (B2-S1)",
	PDTC(0x0060), "HO2S Heater Resistance (B2-S2)",
	PDTC(0x0061), "HO2S Heater Resistance (B2-S3)",
	PDTC(0x0062), "HO2S Heater Control Circuit (B2-S3)",
	PDTC(0x0063), "HO2S Heater Control Circuit Low (B2-S3)",
	PDTC(0x0064), "HO2S Heater Control Circuit High (B2-S3)",
	PDTC(0x0065), "Air Assisted Injector Ctrl. Range/Perf.",
	PDTC(0x0066), "Air Assisted Injector Ctrl. Circuit Low",
	PDTC(0x0067), "Air Assisted Injector Ctrl. Circuit High",
	PDTC(0x0068), "MAP/MAF - Throttle Pos. Correlation",
	PDTC(0x0069), "MAP - Barometric Pressure Correlation",
	PDTC(0x0070), "Ambient Air Temp. Sensor Circuit",
	PDTC(0x0071), "Ambient Air Temp. Sensor Range/Perf.",
	PDTC(0x0072), "Ambient Air Temp. Sensor Circuit Low",
	PDTC(0x0073), "Ambient Air Temp. Sensor Circuit High",
	PDTC(0x0074), "Ambient Air Temp. Sensor Circuit Intermit.",
	PDTC(0x0075), "Intake Valve Ctrl. Sol. Circuit (B1)",
	PDTC(0x0076), "Intake Valve Ctrl. Sol. Circuit Low (B1)",
	PDTC(0x0077), "Intake Valve Ctrl. Sol. Circuit High (B1)",
	PDTC(0x0078), "Exhaust Valve Ctrl. Sol. Circuit (B1)",
	PDTC(0x0079), "Exhaust Valve Ctrl. Sol. Circuit Low (B1)",
	PDTC(0x0080), "Exhaust Valve Ctrl. Sol. Circuit High (B1)",
	PDTC(0x0081), "Intake Valve Ctrl. Sol. Circuit (B2)",
	PDTC(0x0082), "Intake Valve Ctrl. Sol. Circuit Low (B2)",
	PDTC(0x0083), "Intake Valve Ctrl. Sol. Circuit High (B2)",
	PDTC(0x0084), "Exhaust Valve Ctrl. Sol. Circuit (B2)",
	PDTC(0x0085), "Exhaust Valve Ctrl. Sol. Circuit Low (B2)",
	PDTC(0x0086), "Exhaust Valve Ctrl. Sol. Circuit High (B2)",
	PDTC(0x0087), "Fuel Rail/System Pressure - Too Low",
	PDTC(0x0088), "Fuel Rail/System Pressure - Too High",
	PDTC(0x0089), "Fuel Pressure Regulator 1 Perf.",
	PDTC(0x0090), "Fuel Pressure Regulator 1 Control Circuit",
	PDTC(0x0091), "Fuel Pressure Regulator 1 Control Circuit Low",
	PDTC(0x0092), "Fuel Pressure Regulator 1 Control Circuit High",
	PDTC(0x0093), "Fuel System Leak Detected - Large Leak",
	PDTC(0x0094), "Fuel System Leak Detected - Small Leak",
	PDTC(0x0095), "Intake Air Temp. Sensor 2 Circuit",
	PDTC(0x0096), "Intake Air Temp. Sensor 2 Circuit Range/Perf.",
	PDTC(0x0097), "Intake Air Temp. Sensor 2 Circuit Low",
	PDTC(0x0098), "Intake Air Temp. Sensor 2 Circuit High",
	PDTC(0x0099), "Intake Air Temp. Sensor 2 Circuit Intermit.",
	PDTC(0x0100), "Mass or Volume Air Flow Circuit",
	PDTC(0x0101), "Mass or Volume Air Flow Circuit Range/Perf.",
	PDTC(0x0102), "Mass or Volume Air Flow Circuit Low Input",
	PDTC(0x0103), "Mass or Volume Air Flow Circuit High Input",
	PDTC(0x0104), "Mass or Volume Air Flow Circuit Intermit.",
	PDTC(0x0105), "MAP/Barometric Pressure Circuit",
	PDTC(0x0106), "MAP/Barometric Pressure Circuit Range/Perf.",
	PDTC(0x0107), "MAP/Barometric Pressure Circuit Low Input",
	PDTC(0x0108), "MAP/Barometric Pressure Circuit High Input",
	PDTC(0x0109), "MAP/Barometric Pressure Circuit Intermit.",
	PDTC(0x0110), "Intake Air Temp. Sensor 1 Circuit",
	PDTC(0x0111), "Intake Air Temp. Sensor 1 Circuit Range/Perf.",
	PDTC(0x0112), "Intake Air Temp. Sensor 1 Circuit Low",
	PDTC(0x0113), "Intake Air Temp. Sensor 1 Circuit High",
	PDTC(0x0114), "Intake Air Temp. Sensor 1 Circuit Intermit.",
	PDTC(0x0115), "Engine Coolant Temp. Circuit",
	PDTC(0x0116), "Engine Coolant Temp. Circuit Range/Perf.",
	PDTC(0x0117), "Engine Coolant Temp. Circuit Low",
	PDTC(0x0118), "Engine Coolant Temp. Circuit High",
	PDTC(0x0119), "Engine Coolant Temp. Circuit Intermit.",
	PDTC(0x0120), "Throttle Pos. Sensor 'A' Circuit",
	PDTC(0x0121), "Throttle Pos. Sensor 'A' Circuit Range/Perf.",
	PDTC(0x0122), "Throttle Pos. Sensor 'A' Circuit Low",
	PDTC(0x0123), "Throttle Pos. Sensor 'A' Circuit High",
	PDTC(0x0124), "Throttle Pos. Sensor 'A' Circuit Intermit.",
	PDTC(0x0125), "Coolant Temp. Too Low for CL Fuel Control",
	PDTC(0x0126), "Coolant Temp. Too Low for Stable Operation",
	PDTC(0x0127), "Intake Air Temp. Too High",
	PDTC(0x0128), "Coolant Thermostat (Coolant < Reg. Temp.)",
	PDTC(0x0129), "Barometric Pressure Too Low",
	PDTC(0x0130), "O2 Sensor Circuit (B1-S1)",
	PDTC(0x0131), "O2 Sensor Circuit Low Voltage (B1-S1)",
	PDTC(0x0132), "O2 Sensor Circuit High Voltage (B1-S1)",
	PDTC(0x0133), "O2 Sensor Circuit Slow Response (B1-S1)",
	PDTC(0x0134), "O2 Sensor Circuit No Activity Detected (B1-S1)",
	PDTC(0x0135), "O2 Sensor Heater Circuit (B1-S1)",
   PDTC(0x0136), "O2 Sensor Circuit (B1-S2)",
	PDTC(0x0137), "O2 Sensor Circuit Low Voltage (B1-S2)",
	PDTC(0x0138), "O2 Sensor Circuit High Voltage (B1-S2)",
	PDTC(0x0139), "O2 Sensor Circuit Slow Response (B1-S2)",
	PDTC(0x0140), "O2 Sensor Circuit No Activity Detected (B1-S2)",
	PDTC(0x0141), "O2 Sensor Heater Circuit (B1-S2)",
	PDTC(0x0142), "O2 Sensor Circuit (B1-S3)",
	PDTC(0x0143), "O2 Sensor Circuit Low Voltage (B1-S3)",
	PDTC(0x0144), "O2 Sensor Circuit High Voltage (B1-S3)",
	PDTC(0x0145), "O2 Sensor Circuit Slow Response (B1-S3)",
	PDTC(0x0146), "O2 Sensor Circuit No Activity Detected (B1-S3)",
	PDTC(0x0147), "O2 Sensor Heater Circuit (B1-S3)",
	PDTC(0x0148), "Fuel Delivery Error",
	PDTC(0x0149), "Fuel Timing Error",
   PDTC(0x0150), "O2 Sensor Circuit (B2-S1)",
	PDTC(0x0151), "O2 Sensor Circuit Low Voltage (B2-S1)",
	PDTC(0x0152), "O2 Sensor Circuit High Voltage (B2-S1)",
	PDTC(0x0153), "O2 Sensor Circuit Slow Response (B2-S1)",
	PDTC(0x0154), "O2 Sensor Circuit No Activity Detected (B2-S1)",
	PDTC(0x0155), "O2 Sensor Heater Circuit (B2-S1)",
   PDTC(0x0156), "O2 Sensor Circuit (B2-S2)",
	PDTC(0x0157), "O2 Sensor Circuit Low Voltage (B2-S2)",
	PDTC(0x0158), "O2 Sensor Circuit High Voltage (B2-S2)",
	PDTC(0x0159), "O2 Sensor Circuit Slow Response (B2-S2)",
	PDTC(0x0160), "O2 Sensor Circuit No Activity Detected (B2-S2)",
	PDTC(0x0161), "O2 Sensor Heater Circuit (B2-S2)",
   PDTC(0x0162), "O2 Sensor Circuit (B2-S3)",
	PDTC(0x0163), "O2 Sensor Circuit Low Voltage (B2-S3)",
	PDTC(0x0164), "O2 Sensor Circuit High Voltage (B2-S3)",
	PDTC(0x0165), "O2 Sensor Circuit Slow Response (B2-S3)",
	PDTC(0x0166), "O2 Sensor Circuit No Activity Detected (B2-S3)",
	PDTC(0x0167), "O2 Sensor Heater Circuit (B2-S3)",
	PDTC(0x0168), "Fuel Temp. Too High",
	PDTC(0x0169), "Incorrect Fuel Composition",
	PDTC(0x0170), "Fuel Trim (B1)",
	PDTC(0x0171), "System Too Lean (B1)",
	PDTC(0x0172), "System Too Rich (B1)",
	PDTC(0x0173), "Fuel Trim (B2)",
	PDTC(0x0174), "System Too Lean (B2)",
	PDTC(0x0175), "System Too Rich (B2)",
	PDTC(0x0176), "Fuel Composition Sensor Circuit",
	PDTC(0x0177), "Fuel Composition Sensor Circuit Range/Perf.",
	PDTC(0x0178), "Fuel Composition Sensor Circuit Low",
	PDTC(0x0179), "Fuel Composition Sensor Circuit High",
	PDTC(0x0180), "Fuel Composition Sensor A Circuit",
	PDTC(0x0181), "Fuel Composition Sensor A Circuit Range/Perf.",
	PDTC(0x0182), "Fuel Composition Sensor A Circuit Low",
	PDTC(0x0183), "Fuel Composition Sensor A Circuit High",
	PDTC(0x0184), "Fuel Composition Sensor A Circuit Intermit.",
	PDTC(0x0185), "Fuel Composition Sensor B Circuit",
	PDTC(0x0186), "Fuel Composition Sensor B Circuit Range/Perf.",
	PDTC(0x0187), "Fuel Composition Sensor B Circuit Low",
	PDTC(0x0188), "Fuel Composition Sensor B Circuit High",
	PDTC(0x0189), "Fuel Composition Sensor B Circuit Intermit.",
	PDTC(0x0190), "Fuel Rail Pressure Sensor Circuit",
	PDTC(0x0191), "Fuel Rail Pressure Sensor Circuit Range/Perf.",
	PDTC(0x0192), "Fuel Rail Pressure Sensor Circuit Low",
	PDTC(0x0193), "Fuel Rail Pressure Sensor Circuit High",
	PDTC(0x0194), "Fuel Rail Pressure Sensor Circuit Intermit.",
	PDTC(0x0195), "Engine Oil Temp. Sensor",
	PDTC(0x0196), "Engine Oil Temp. Sensor Range/Perf.",
	PDTC(0x0197), "Engine Oil Temp. Sensor Low",
	PDTC(0x0198), "Engine Oil Temp. Sensor High",
	PDTC(0x0199), "Engine Oil Temp. Sensor Intermit.",
	PDTC(0x0200), "Injector Circuit",
	PDTC(0x0201), "Injector Circuit - Cylinder 1",
	PDTC(0x0202), "Injector Circuit - Cylinder 2",
	PDTC(0x0203), "Injector Circuit - Cylinder 3",
	PDTC(0x0204), "Injector Circuit - Cylinder 4",
	PDTC(0x0205), "Injector Circuit - Cylinder 5",
	PDTC(0x0206), "Injector Circuit - Cylinder 6",
	PDTC(0x0207), "Injector Circuit - Cylinder 7",
	PDTC(0x0208), "Injector Circuit - Cylinder 8",
	PDTC(0x0209), "Injector Circuit - Cylinder 9",
	PDTC(0x0210), "Injector Circuit - Cylinder 10",
	PDTC(0x0211), "Injector Circuit - Cylinder 11",
	PDTC(0x0212), "Injector Circuit - Cylinder 12",
	PDTC(0x0213), "Cold Start Injector 1",
	PDTC(0x0214), "Cold Start Injector 2",
	PDTC(0x0215), "Engine Shutoff Sol.",
	PDTC(0x0216), "Injector/Injection Timing Control Circuit",
	PDTC(0x0217), "Engine Coolant Over Temp. Condition",
	PDTC(0x0218), "Trans. Fluid Over Temp. Condition",
	PDTC(0x0219), "Engine Overspeed Condition",
	PDTC(0x0220), "Throttle Pos. Sensor 'B' Circuit",
	PDTC(0x0221), "Throttle Pos. Sensor 'B' Circuit Range/Perf.",
	PDTC(0x0222), "Throttle Pos. Sensor 'B' Circuit Low",
	PDTC(0x0223), "Throttle Pos. Sensor 'B' Circuit High",
	PDTC(0x0224), "Throttle Pos. Sensor 'B' Circuit Intermit.",
	PDTC(0x0225), "Throttle Pos. Sensor 'C' Circuit",
	PDTC(0x0226), "Throttle Pos. Sensor 'C' Circuit Range/Perf.",
	PDTC(0x0227), "Throttle Pos. Sensor 'C' Circuit Low",
	PDTC(0x0228), "Throttle Pos. Sensor 'C' Circuit High",
	PDTC(0x0229), "Throttle Pos. Sensor 'C' Circuit Intermit.",
	PDTC(0x0230), "Fuel Pump Primary Circuit",
	PDTC(0x0231), "Fuel Pump Secondary Circuit Low",
	PDTC(0x0232), "Fuel Pump Secondary Circuit High",
	PDTC(0x0233), "Fuel Pump Secondary Circuit Intermit.",
	PDTC(0x0234), "Turbo Overboost Condition",
	PDTC(0x0235), "Turbo Boost Sensor 'A' Circuit",
	PDTC(0x0236), "Turbo Boost Sensor 'A' Circuit Range/Perf.",
	PDTC(0x0237), "Turbo Boost Sensor 'A' Circuit Low",
	PDTC(0x0238), "Turbo Boost Sensor 'A' Circuit High",
	PDTC(0x0239), "Turbo Boost Sensor 'B' Circuit",
	PDTC(0x0240), "Turbo Boost Sensor 'B' Circuit Range/Perf.",
	PDTC(0x0241), "Turbo Boost Sensor 'B' Circuit Low",
	PDTC(0x0242), "Turbo Boost Sensor 'B' Circuit High",
	PDTC(0x0243), "Turbo Wastegate Sol. 'A'",
	PDTC(0x0244), "Turbo Wastegate Sol. 'A' Range/Perf.",
	PDTC(0x0245), "Turbo Wastegate Sol. 'A' Low",
	PDTC(0x0246), "Turbo Wastegate Sol. 'A' High",
	PDTC(0x0247), "Turbo Wastegate Sol. 'B'",
	PDTC(0x0248), "Turbo Wastegate Sol. 'B' Range/Perf.",
	PDTC(0x0249), "Turbo Wastegate Sol. 'B' Low",
	PDTC(0x0250), "Turbo Wastegate Sol. 'B' High",
	PDTC(0x0251), "Inj. Pump Fuel Metering Control 'A'",
	PDTC(0x0252), "Inj. Pump Fuel Metering Control 'A' Range/Perf.",
	PDTC(0x0253), "Inj. Pump Fuel Metering Control 'A' Low",
	PDTC(0x0254), "Inj. Pump Fuel Metering Control 'A' High",
	PDTC(0x0255), "Inj. Pump Fuel Metering Control 'A' Interm.",
	PDTC(0x0256), "Inj. Pump Fuel Metering Control 'B'",
	PDTC(0x0257), "Inj. Pump Fuel Metering Control 'B' Range/Perf.",
	PDTC(0x0258), "Inj. Pump Fuel Metering Control 'B' Low",
	PDTC(0x0259), "Inj. Pump Fuel Metering Control 'B' High",
	PDTC(0x0260), "Inj. Pump Fuel Metering Control 'B' Interm.",
	PDTC(0x0261), "Cylinder 1 Injector Circuit Low",
	PDTC(0x0262), "Cylinder 1 Injector Circuit High",
	PDTC(0x0263), "Cylinder 1 Contribution/Balance",
	PDTC(0x0264), "Cylinder 2 Injector Circuit Low",
	PDTC(0x0265), "Cylinder 2 Injector Circuit High",
	PDTC(0x0266), "Cylinder 2 Contribution/Balance",
	PDTC(0x0267), "Cylinder 3 Injector Circuit Low",
	PDTC(0x0268), "Cylinder 3 Injector Circuit High",
	PDTC(0x0269), "Cylinder 3 Contribution/Balance",
	PDTC(0x0270), "Cylinder 4 Injector Circuit Low",
	PDTC(0x0271), "Cylinder 4 Injector Circuit High",
	PDTC(0x0272), "Cylinder 4 Contribution/Balance",
	PDTC(0x0273), "Cylinder 5 Injector Circuit Low",
	PDTC(0x0274), "Cylinder 5 Injector Circuit High",
	PDTC(0x0275), "Cylinder 5 Contribution/Balance",
	PDTC(0x0276), "Cylinder 6 Injector Circuit Low",
	PDTC(0x0277), "Cylinder 6 Injector Circuit High",
	PDTC(0x0278), "Cylinder 6 Contribution/Balance",
	PDTC(0x0279), "Cylinder 7 Injector Circuit Low",
	PDTC(0x0280), "Cylinder 7 Injector Circuit High",
	PDTC(0x0281), "Cylinder 7 Contribution/Balance",
	PDTC(0x0282), "Cylinder 8 Injector Circuit Low",
	PDTC(0x0283), "Cylinder 8 Injector Circuit High",
	PDTC(0x0284), "Cylinder 8 Contribution/Balance",
	PDTC(0x0285), "Cylinder 9 Injector Circuit Low",
	PDTC(0x0286), "Cylinder 9 Injector Circuit High",
	PDTC(0x0287), "Cylinder 9 Contribution/Balance",
	PDTC(0x0288), "Cylinder 10 Injector Circuit Low",
	PDTC(0x0289), "Cylinder 10 Injector Circuit High",
	PDTC(0x0290), "Cylinder 10 Contribution/Balance",
	PDTC(0x0291), "Cylinder 11 Injector Circuit Low",
	PDTC(0x0292), "Cylinder 11 Injector Circuit High",
	PDTC(0x0293), "Cylinder 11 Contribution/Balance",
	PDTC(0x0294), "Cylinder 12 Injector Circuit Low",
	PDTC(0x0295), "Cylinder 12 Injector Circuit High",
	PDTC(0x0296), "Cylinder 12 Contribution/Balance",
	PDTC(0x0297), "Vehicle Overspeed Condition",
	PDTC(0x0298), "Engine Oil Over Temp.",
	PDTC(0x0299), "Turbo/Super Charger Underboost",
	PDTC(0x0300), "Random/Multiple Cylinder Misfire Detected",
	PDTC(0x0301), "Cylinder 1 Misfire Detected",
	PDTC(0x0302), "Cylinder 2 Misfire Detected",
	PDTC(0x0303), "Cylinder 3 Misfire Detected",
	PDTC(0x0304), "Cylinder 4 Misfire Detected",
	PDTC(0x0305), "Cylinder 5 Misfire Detected",
	PDTC(0x0306), "Cylinder 6 Misfire Detected",
	PDTC(0x0307), "Cylinder 7 Misfire Detected",
	PDTC(0x0308), "Cylinder 8 Misfire Detected",
	PDTC(0x0309), "Cylinder 9 Misfire Detected",
	PDTC(0x0310), "Cylinder 10 Misfire Detected",
	PDTC(0x0311), "Cylinder 11 Misfire Detected",
	PDTC(0x0312), "Cylinder 12 Misfire Detected",
	PDTC(0x0313), "Misfire Detected with Low Fuel",
	PDTC(0x0314), "Single Cylinder Misfire (Cylinder not Specified)",
	PDTC(0x0315), "Crankshaft Pos. System Variation Not Learned",
	PDTC(0x0316), "Engine Misfire Detected on Startup",
	PDTC(0x0317), "Rough Road Hardware Not Present",
	PDTC(0x0318), "Rough Road Sensor 'A' Signal Circuit",
	PDTC(0x0319), "Rough Road Sensor 'B'",
	PDTC(0x0320), "Ign./Dist. Engine Speed Input Circuit",
	PDTC(0x0321), "Ign./Dist. Engine Speed Input Circuit Range/Perf.",
	PDTC(0x0322), "Ign./Dist. Engine Speed Input Circuit No Signal",
	PDTC(0x0323), "Ign./Dist. Engine Speed Input Circuit Interm.",
	PDTC(0x0324), "Knock Control System Error",
	PDTC(0x0325), "Knock Sensor 1 Circuit (B1)",
	PDTC(0x0326), "Knock Sensor 1 Circuit Range/Perf. (B1)",
	PDTC(0x0327), "Knock Sensor 1 Circuit Low (B1)",
	PDTC(0x0328), "Knock Sensor 1 Circuit High (B1)",
	PDTC(0x0329), "Knock Sensor 1 Circuit Input Interm. (B1)",
	PDTC(0x0330), "Knock Sensor 2 Circuit (B2)",
	PDTC(0x0331), "Knock Sensor 2 Circuit Range/Perf. (B2)",
	PDTC(0x0332), "Knock Sensor 2 Circuit Low (B2)",
	PDTC(0x0333), "Knock Sensor 2 Circuit High (B2)",
	PDTC(0x0334), "Knock Sensor 2 Circuit Input Interm. (B2)",
	PDTC(0x0335), "Crankshaft Pos. Sensor 'A' Circuit",
	PDTC(0x0336), "Crankshaft Pos. Sensor 'A' Circuit Range/Perf.",
	PDTC(0x0337), "Crankshaft Pos. Sensor 'A' Circuit Low",
	PDTC(0x0338), "Crankshaft Pos. Sensor 'A' Circuit High",
	PDTC(0x0339), "Crankshaft Pos. Sensor 'A' Circuit Interm.",
	PDTC(0x0340), "Camshaft Pos. Sensor 'A' Circuit (B1)",
	PDTC(0x0341), "Camshaft Pos. Sensor 'A' Circuit Range/Perf. (B1)",
	PDTC(0x0342), "Camshaft Pos. Sensor 'A' Circuit Low (B1)",
	PDTC(0x0343), "Camshaft Pos. Sensor 'A' Circuit High (B1)",
	PDTC(0x0344), "Camshaft Pos. Sensor 'A' Circuit Interm. (B1)",
	PDTC(0x0345), "Camshaft Pos. Sensor 'A' Circuit (B2)",
	PDTC(0x0346), "Camshaft Pos. Sensor 'A' Circuit Range/Perf. (B2)",
	PDTC(0x0347), "Camshaft Pos. Sensor 'A' Circuit Low (B2)",
	PDTC(0x0348), "Camshaft Pos. Sensor 'A' Circuit High (B2)",
	PDTC(0x0349), "Camshaft Pos. Sensor 'A' Circuit Interm. (B2)",
	PDTC(0x0350), "Ign. Coil Primary/Secondary Circuit",
	PDTC(0x0351), "Ign. Coil 'A' Primary/Secondary Circuit",
	PDTC(0x0352), "Ign. Coil 'B' Primary/Secondary Circuit",
	PDTC(0x0353), "Ign. Coil 'C' Primary/Secondary Circuit",
	PDTC(0x0354), "Ign. Coil 'D' Primary/Secondary Circuit",
	PDTC(0x0355), "Ign. Coil 'E' Primary/Secondary Circuit",
	PDTC(0x0356), "Ign. Coil 'F' Primary/Secondary Circuit",
	PDTC(0x0357), "Ign. Coil 'G' Primary/Secondary Circuit",
	PDTC(0x0358), "Ign. Coil 'H' Primary/Secondary Circuit",
	PDTC(0x0359), "Ign. Coil 'I' Primary/Secondary Circuit",
	PDTC(0x0360), "Ign. Coil 'J' Primary/Secondary Circuit",
	PDTC(0x0361), "Ign. Coil 'K' Primary/Secondary Circuit",
	PDTC(0x0362), "Ign. Coil 'L' Primary/Secondary Circuit",
	PDTC(0x0363), "Misfire Detected - Fueling Disabled",
	PDTC(0x0364), "Reserved!?",
	PDTC(0x0365), "Camshaft Pos. Sensor 'B' Circuit (B1)",
	PDTC(0x0366), "Camshaft Pos. Sensor 'B' Circuit Range/Perf. (B1)",
	PDTC(0x0367), "Camshaft Pos. Sensor 'B' Circuit Low (B1)",
	PDTC(0x0368), "Camshaft Pos. Sensor 'B' Circuit High (B1)",
	PDTC(0x0369), "Camshaft Pos. Sensor 'B' Circuit Interm. (B1)",
	PDTC(0x0370), "Timing Ref. High Res. Signal 'A'",
	PDTC(0x0371), "Timing Ref. High Res. Signal 'A' Too Many Pulses",
	PDTC(0x0372), "Timing Ref. High Res. Signal 'A' Too Few Pulses",
	PDTC(0x0373), "Timing Ref. High Res. Signal 'A' Interm.",
	PDTC(0x0374), "Timing Ref. High Res. Signal 'A' No Pulse",
	PDTC(0x0375), "Timing Ref. High Res. Signal 'B'",
	PDTC(0x0376), "Timing Ref. High Res. Signal 'B' Too Many Pulses",
	PDTC(0x0377), "Timing Ref. High Res. Signal 'B' Too Few Pulses",
	PDTC(0x0378), "Timing Ref. High Res. Signal 'B' Interm.",
	PDTC(0x0379), "Timing Ref. High Res. Signal 'B' No Pulse",
	PDTC(0x0380), "Glow Plug/Heater Circuit 'A'",
	PDTC(0x0381), "Glow Plug/Heater Indicator Circuit",
	PDTC(0x0382), "Glow Plug/Heater Circuit 'B'",
	PDTC(0x0383), "Reserved!?",
	PDTC(0x0384), "Reserved!?",
	PDTC(0x0385), "Camshaft Pos. Sensor 'B' Circuit",
	PDTC(0x0386), "Camshaft Pos. Sensor 'B' Circuit Range/Perf.",
	PDTC(0x0387), "Camshaft Pos. Sensor 'B' Circuit Low",
	PDTC(0x0388), "Camshaft Pos. Sensor 'B' Circuit High",
	PDTC(0x0389), "Camshaft Pos. Sensor 'B' Circuit Intermit.",
	PDTC(0x0390), "Camshaft Pos. Sensor 'B' Circuit (B2)",
	PDTC(0x0391), "Camshaft Pos. Sensor 'B' Circuit Range/Perf. (B2)",
	PDTC(0x0392), "Camshaft Pos. Sensor 'B' Circuit Low (B2)",
	PDTC(0x0393), "Camshaft Pos. Sensor 'B' Circuit High (B2)",
	PDTC(0x0394), "Camshaft Pos. Sensor 'B' Circuit Intermit. (B2)",
	PDTC(0x0400), "Exhaust Gas Recirc. Flow",
	PDTC(0x0401), "Exhaust Gas Recirc. Flow Insufficient Detected",
	PDTC(0x0402), "Exhaust Gas Recirc. Flow Excessive Detected",
	PDTC(0x0403), "Exhaust Gas Recirc. Control Circuit Range/Perf.",
	PDTC(0x0404), "Exhaust Gas Recirc. Control Circuit",
	PDTC(0x0405), "Exhaust Gas Recirc. Sensor 'A' Circuit Low",
	PDTC(0x0406), "Exhaust Gas Recirc. Sensor 'A' Circuit High",
	PDTC(0x0407), "Exhaust Gas Recirc. Sensor 'B' Circuit Low",
	PDTC(0x0408), "Exhaust Gas Recirc. Sensor 'B' Circuit High",
	PDTC(0x0409), "Exhaust Gas Recirc. Sensor 'A' Circuit",
	PDTC(0x0410), "Sec. Air Inj. System",
	PDTC(0x0411), "Sec. Air Inj. System Incorrect Flow Detected",
	PDTC(0x0412), "Sec. Air Inj. System Switching Valve 'A' Circuit",
	PDTC(0x0413), "Sec. Air Inj. System Switching Valve 'A' Circuit Open",
	PDTC(0x0414), "Sec. Air Inj. System Switching Valve 'A' Circuit Shorted",
	PDTC(0x0415), "Sec. Air Inj. System Switching Valve 'B' Circuit",
	PDTC(0x0416), "Sec. Air Inj. System Switching Valve 'B' Circuit Open",
	PDTC(0x0417), "Sec. Air Inj. System Switching Valve 'B' Circuit Shorted",
	PDTC(0x0418), "Sec. Air Inj. System Control 'A' Circuit",
	PDTC(0x0419), "Sec. Air Inj. System Control 'B' Circuit",
	PDTC(0x0420), "Catalyst System Efficiency Below Threshold (B1)",
	PDTC(0x0421), "Warm Up Catalyst Efficiency Below Threshold (B1)",
	PDTC(0x0422), "Main Catalyst Efficiency Below Threshold (B1)",
	PDTC(0x0423), "Heated Catalyst Efficiency Below Threshold (B1)",
	PDTC(0x0424), "Heated Catalyst Temp. Below Threshold (B1)",
	PDTC(0x0425), "Catalyst Temp. Sensor (B1)",
	PDTC(0x0426), "Catalyst Temp. Sensor Range/Perf. (B1)",
	PDTC(0x0427), "Catalyst Temp. Sensor Low (B1)",
	PDTC(0x0428), "Catalyst Temp. Sensor High (B1)",
	PDTC(0x0429), "Catalyst Heater Control Circuit (B1)",
	PDTC(0x0430), "Catalyst System Efficiency Below Threshold (B2)",
	PDTC(0x0431), "Warm Up Catalyst Efficiency Below Threshold (B2)",
	PDTC(0x0432), "Main Catalyst Efficiency Below Threshold (B2)",
	PDTC(0x0433), "Heated Catalyst Efficiency Below Threshold (B2)",
	PDTC(0x0434), "Heated Catalyst Temp. Below Threshold (B2)",
	PDTC(0x0435), "Catalyst Temp. Sensor (B2)",
	PDTC(0x0436), "Catalyst Temp. Sensor Range/Perf. (B2)",
	PDTC(0x0437), "Catalyst Temp. Sensor Low (B2)",
	PDTC(0x0438), "Catalyst Temp. Sensor High (B2)",
	PDTC(0x0439), "Catalyst Heater Control Circuit (B2)",
	PDTC(0x0440), "Evap. Emission System",
	PDTC(0x0441), "Evap. Emission System Incorrect Purge Flow",
	PDTC(0x0442), "Evap. Emission System Leak Detected (small leak)",
	PDTC(0x0443), "Evap. Emission System Purge Control Valve Circuit",
	PDTC(0x0444), "Evap. Emission System Purge Control Valve Circuit Open",
	PDTC(0x0445), "Evap. Emission System Purge Control Valve Circuit Shorted",
	PDTC(0x0446), "Evap. Emission System Vent Control Circuit",
	PDTC(0x0447), "Evap. Emission System Vent Control Circuit Open",
	PDTC(0x0448), "Evap. Emission System Vent Control Circuit Shorted",
	PDTC(0x0449), "Evap. Emission System Vent Valve/Sol. Circuit",
	PDTC(0x0450), "Evap. Emission System Pres. Sensor/Switch",
	PDTC(0x0451), "Evap. Emission System Pres. Sensor/Switch Range/Perf.",
	PDTC(0x0452), "Evap. Emission System Pres. Sensor/Switch Low",
	PDTC(0x0453), "Evap. Emission System Pres. Sensor/Switch High",
	PDTC(0x0454), "Evap. Emission System Pres. Sensor/Switch Intermit.",
	PDTC(0x0455), "Evap. Emission System Leak Detected (large leak)",
	PDTC(0x0456), "Evap. Emission System Leak Detected (very small leak)",
	PDTC(0x0457), "Evap. Emission System Leak Detected (fuel cap loose/off)",
	PDTC(0x0458), "Evap. Emission System Purge Control Valve Circuit Low",
	PDTC(0x0459), "Evap. Emission System Purge Control Valve Circuit High",
	PDTC(0x0460), "Fuel Level Sensor 'A' Circuit",
	PDTC(0x0461), "Fuel Level Sensor 'A' Circuit Range/Perf.",
	PDTC(0x0462), "Fuel Level Sensor 'A' Circuit Low",
	PDTC(0x0463), "Fuel Level Sensor 'A' Circuit High",
	PDTC(0x0464), "Fuel Level Sensor 'A' Circuit Intermit.",
	PDTC(0x0465), "EVAP Purge Flow Sensor Circuit",
	PDTC(0x0466), "EVAP Purge Flow Sensor Circuit Range/Perf.",
	PDTC(0x0467), "EVAP Purge Flow Sensor Circuit Low",
	PDTC(0x0468), "EVAP Purge Flow Sensor Circuit High",
	PDTC(0x0469), "EVAP Purge Flow Sensor Circuit Intermit.",
	PDTC(0x0470), "Exhaust Pres. Sensor",
	PDTC(0x0471), "Exhaust Pres. Sensor Range/Perf.",
	PDTC(0x0472), "Exhaust Pres. Sensor Low",
	PDTC(0x0473), "Exhaust Pres. Sensor High",
	PDTC(0x0474), "Exhaust Pres. Sensor Intermit.",
	PDTC(0x0475), "Exhaust Pres. Control Valve",
	PDTC(0x0476), "Exhaust Pres. Control Valve Range/Perf.",
	PDTC(0x0477), "Exhaust Pres. Control Valve Low",
	PDTC(0x0478), "Exhaust Pres. Control Valve High",
	PDTC(0x0479), "Exhaust Pres. Control Valve Intermit.",
	PDTC(0x0480), "Fan 1 Control Circuit",
	PDTC(0x0481), "Fan 2 Control Circuit",
	PDTC(0x0482), "Fan 3 Control Circuit",
	PDTC(0x0483), "Fan Rationality Check",
	PDTC(0x0484), "Fan Circuit Over Current",
	PDTC(0x0485), "Fan Power/Ground Circuit",
	PDTC(0x0486), "Exhaust Gas Recirc. Sensor 'B' Circuit",
	PDTC(0x0487), "Exhaust Gas Recirc. Throttle Pos. Control Circuit",
	PDTC(0x0488), "Exhaust Gas Recirc. Throttle Pos. Control Range/Perf.",
	PDTC(0x0489), "Exhaust Gas Recirc. Control Circuit Low",
	PDTC(0x0490), "Exhaust Gas Recirc. Control Circuit High",
	PDTC(0x0491), "Sec. Air Inj. System Insufficient Flow (B1)",
	PDTC(0x0492), "Sec. Air Inj. System Insufficient Flow (B2)",
	PDTC(0x0493), "Fan Overspeed",
	PDTC(0x0494), "Fan Speed Low",
	PDTC(0x0495), "Fan Speed High",
	PDTC(0x0496), "Evap. Emission System High Purge Flow",
	PDTC(0x0497), "Evap. Emission System Low Purge Flow",
	PDTC(0x0498), "Evap. Emission System Vent Valve Control Circuit Low",
	PDTC(0x0499), "Evap. Emission System Vent Valve Control Circuit High",
	PDTC(0x0500), "Vehicle Speed Sensor 'A'",
	PDTC(0x0501), "Vehicle Speed Sensor 'A' Range/Perf.",
	PDTC(0x0502), "Vehicle Speed Sensor 'A' Circuit Low Input",
	PDTC(0x0503), "Vehicle Speed Sensor 'A' Intermit.",
	PDTC(0x0504), "Brake Switch A/B Correlation",
	PDTC(0x0505), "Idle Air Control System",
	PDTC(0x0506), "Idle Air Control System RPM Lower than Expected",
	PDTC(0x0507), "Idle Air Control System RPM Higher than Expected",
	PDTC(0x0508), "Idle Air Control System Circuit Low",
	PDTC(0x0509), "Idle Air Control System Circuit High",
	PDTC(0x0510), "Closed Throttle Pos. Switch",
	PDTC(0x0511), "Idle Air Control Circuit",
	PDTC(0x0512), "Starter Request Circuit",
	PDTC(0x0513), "Incorrect Immobilizer Key",
	PDTC(0x0514), "Battery Temp. Sensor Circuit Range/Perf.",
	PDTC(0x0515), "Battery Temp. Sensor Circuit",
	PDTC(0x0516), "Battery Temp. Sensor Circuit Low",
	PDTC(0x0517), "Battery Temp. Sensor Circuit Hight",
	PDTC(0x0518), "Idle Air Control Circuit Intermit.",
	PDTC(0x0519), "Idle Air Control System Perf.",
	PDTC(0x0520), "Engine Oil Pres. Sensor Circuit",
	PDTC(0x0521), "Engine Oil Pres. Sensor Range/Perf.",
	PDTC(0x0522), "Engine Oil Pres. Sensor Low Voltage",
	PDTC(0x0523), "Engine Oil Pres. Sensor High Voltage",
	PDTC(0x0524), "Engine Oil Pres. Too Low",
	PDTC(0x0525), "Cruise Control Servo Control Circuit Range/Perf.",
	PDTC(0x0526), "Fan Speed Sensor Circuit",
	PDTC(0x0527), "Fan Speed Sensor Circuit Range/Perf.",
	PDTC(0x0528), "Fan Speed Sensor Circuit No Signal",
	PDTC(0x0529), "Fan Speed Sensor Circuit Intermit.",
	PDTC(0x0530), "AC Refrigerant Pres. Sensor 'A' Circuit",
	PDTC(0x0531), "AC Refrigerant Pres. Sensor 'A' Circuit Range/Perf.",
	PDTC(0x0532), "AC Refrigerant Pres. Sensor 'A' Circuit Low",
	PDTC(0x0533), "AC Refrigerant Pres. Sensor 'A' Circuit High",
	PDTC(0x0534), "AC Refrigerant Charge Loss",
	PDTC(0x0535), "AC Evaporator Temp. Sensor Circuit",
	PDTC(0x0536), "AC Evaporator Temp. Sensor Circuit Range/Perf.",
	PDTC(0x0537), "AC Evaporator Temp. Sensor Circuit Low",
	PDTC(0x0538), "AC Evaporator Temp. Sensor Circuit High",
	PDTC(0x0539), "AC Evaporator Temp. Sensor Circuit Intermit.",
	PDTC(0x0540), "Intake Air Heater 'A' Circuit",
	PDTC(0x0541), "Intake Air Heater 'A' Circuit Low",
	PDTC(0x0542), "Intake Air Heater 'A' Circuit High",
	PDTC(0x0543), "Intake Air Heater 'A' Circuit Open",
	PDTC(0x0544), "Exhaust Gas Temp. Sensor Circuit (B1-S1)",
	PDTC(0x0545), "Exhaust Gas Temp. Sensor Circuit Low (B1-S1)",
	PDTC(0x0546), "Exhaust Gas Temp. Sensor Circuit High (B1-S1)",
	PDTC(0x0547), "Exhaust Gas Temp. Sensor Circuit (B2-S1)",
	PDTC(0x0548), "Exhaust Gas Temp. Sensor Circuit Low (B2-S1)",
	PDTC(0x0549), "Exhaust Gas Temp. Sensor Circuit High (B2-S1)",
	PDTC(0x0550), "Power Steering Pres. Sensor Circuit",
	PDTC(0x0551), "Power Steering Pres. Sensor Circuit Range/Perf.",
	PDTC(0x0552), "Power Steering Pres. Sensor Circuit Low Input",
	PDTC(0x0553), "Power Steering Pres. Sensor Circuit High Input",
	PDTC(0x0554), "Power Steering Pres. Sensor Circuit Intermit.",
	PDTC(0x0555), "Brake Booster Pres. Sensor Circuit",
	PDTC(0x0556), "Brake Booster Pres. Sensor Circuit Range/Perf.",
	PDTC(0x0557), "Brake Booster Pres. Sensor Circuit Low Input",
	PDTC(0x0558), "Brake Booster Pres. Sensor Circuit High Input",
	PDTC(0x0559), "Brake Booster Pres. Sensor Circuit Intermit.",
	PDTC(0x0560), "System Voltage",
	PDTC(0x0561), "System Voltage Unstable",
	PDTC(0x0562), "System Voltage Low",
	PDTC(0x0563), "System Voltage High",
	PDTC(0x0564), "Cruise Control Multi-Func. Input 'A' Circuit",
	PDTC(0x0565), "Cruise Control On Signal",
	PDTC(0x0566), "Cruise Control Off Signal",
	PDTC(0x0567), "Cruise Control Resume Signal",
	PDTC(0x0568), "Cruise Control Set Signal",
	PDTC(0x0569), "Cruise Control Coast Signal",
	PDTC(0x0570), "Cruise Control Accel. Signal",
	PDTC(0x0571), "Brake Switch 'A' Circuit",
	PDTC(0x0572), "Brake Switch 'A' Circuit Low",
	PDTC(0x0573), "Brake Switch 'A' Circuit High",
	PDTC(0x0574), "Cruise Control System - Vehicle Speed Too High",
	PDTC(0x0575), "Cruise Control Input Circuit",
	PDTC(0x0576), "Cruise Control Input Circuit Low",
	PDTC(0x0577), "Cruise Control Input Circuit High",
	PDTC(0x0578), "Cruise Control Multi-Func. Inp. 'A' Ckt. Stuck",
	PDTC(0x0579), "Cruise Control Multi-Func. Inp. 'A' Ckt. Range/Perf.",
	PDTC(0x0580), "Cruise Control Multi-Func. Inp. 'A' Ckt. Low",
	PDTC(0x0581), "Cruise Control Multi-Func. Inp. 'A' Ckt. High",
	PDTC(0x0582), "Cruise Control Vac. Control Circuit",
	PDTC(0x0583), "Cruise Control Vac. Control Circuit Low",
	PDTC(0x0584), "Cruise Control Vac. Control Circuit High",
	PDTC(0x0585), "Cruise Control Multi-Func. Inp. A/B Correlation",
	PDTC(0x0586), "Cruise Control Vent Control Circuit",
	PDTC(0x0587), "Cruise Control Vent Control Circuit Low",
	PDTC(0x0588), "Cruise Control Vent Control Circuit High",
	PDTC(0x0589), "Cruise Control Multi-Func. Inp. 'B' Circuit",
	PDTC(0x0590), "Cruise Control Multi-Func. Inp. 'B' Ckt. Stuck",
	PDTC(0x0591), "Cruise Control Multi-Func. Inp. 'B' Ckt. Range/Perf.",
	PDTC(0x0592), "Cruise Control Multi-Func. Inp. 'B' Ckt. Low",
	PDTC(0x0593), "Cruise Control Multi-Func. Inp. 'B' Ckt. High",
	PDTC(0x0594), "Cruise Control Servo Control Circuit",
	PDTC(0x0595), "Cruise Control Servo Control Circuit Low",
	PDTC(0x0596), "Cruise Control Serve Control Circuit High",
	PDTC(0x0597), "Thermostat Heater Control Circuit",
	PDTC(0x0598), "Thermostat Heater Control Circuit Low",
	PDTC(0x0599), "Thermostat Heater Control Circuit High",
	PDTC(0x0600), "Serial Comm. Link",
	PDTC(0x0601), "Control Module Memory Checksum Error",
	PDTC(0x0602), "Control Module Programming Error",
	PDTC(0x0603), "Control Module Keep Alive Memory (KAM) Error",
	PDTC(0x0604), "Control Module RAM Error",
	PDTC(0x0605), "Control Module ROM Error",
	PDTC(0x0606), "ECM/PCM Processor",
	PDTC(0x0607), "Control Module Perf.",
	PDTC(0x0608), "Control Module VSS Output 'A'",
	PDTC(0x0609), "Control Module VSS Output 'B'",
	PDTC(0x0610), "Control Module Vehicle Options Error",
	PDTC(0x0611), "Fuel Injector Control Module Perf.",
	PDTC(0x0612), "Fuel Injector Control Module Relay Control",
	PDTC(0x0613), "TCM Processor",
	PDTC(0x0614), "ECM/TCM Incompatible",
	PDTC(0x0615), "Starter Relay Circuit",
	PDTC(0x0616), "Starter Relay Circuit Low",
	PDTC(0x0617), "Starter Relay Circuit High",
	PDTC(0x0618), "Alternative Fuel Control Module KAM Error",
	PDTC(0x0619), "Alternative Fuel Control Module RAM/ROM Error",
	PDTC(0x0620), "Generator Control Circuit",
	PDTC(0x0621), "Generator Lamp/L Terminal Circuit",
	PDTC(0x0622), "Generator Field/F Terminal Circuit",
	PDTC(0x0623), "Generator Lamp Control Circuit",
	PDTC(0x0624), "Fuel Cap Lamp Control Circuit",
	PDTC(0x0625), "Generator Field/F Terminal Circuit Low",
	PDTC(0x0626), "Generator Field/F Terminal Circuit High",
	PDTC(0x0627), "Fuel Pump 'A' Control Circuit",
	PDTC(0x0628), "Fuel Pump 'A' Control Circuit Low",
	PDTC(0x0629), "Fuel Pump 'A' Control Circuit High",
	PDTC(0x0630), "VIN Not Programmed or Incompatible-ECM/PCM",
	PDTC(0x0631), "VIN Not Programmed or Incompatible-TCM",
	PDTC(0x0632), "Odometer Not Programmed-ECM/PCM",
	PDTC(0x0633), "Immobilizer Key Not Programmed-ECM/PCM",
	PDTC(0x0634), "PCM/ECM/TCM Internal Temp. Too High",
	PDTC(0x0635), "Power Steering Control Circuit",
	PDTC(0x0636), "Power Steering Control Circuit Low",
	PDTC(0x0637), "Power Steering Control Circuit High",
	PDTC(0x0638), "Throttle Actuator Control Range/Perf. (B1)",
	PDTC(0x0639), "Throttle Actuator Control Range/Perf. (B2)",
	PDTC(0x0640), "Intake Air Heater Control Circuit",
	PDTC(0x0641), "Sensor Reference Voltage 'A' Circuit",
	PDTC(0x0642), "Sensor Reference Voltage 'A' Circuit Low",
	PDTC(0x0643), "Sensor Reference Voltage 'A' Circuit High",
	PDTC(0x0644), "Driver Display Serial Comm. Circuit",
	PDTC(0x0645), "A/C Clutch Relay Control Circuit",
	PDTC(0x0646), "A/C Clutch Relay Control Circuit Low",
	PDTC(0x0647), "A/C Clutch Relay Control Circuit High",
	PDTC(0x0648), "Immobilizer Lamp Control Circuit",
	PDTC(0x0649), "Speed Control Lamp Control Circuit",
	PDTC(0x0650), "Malfunction Indicator Lamp (MIL) Control Circuit",
	PDTC(0x0651), "Sensor Reference Voltage 'B' Circuit",
	PDTC(0x0652), "Sensor Reference Voltage 'B' Circuit Low",
	PDTC(0x0653), "Sensor Reference Voltage 'B' Circuit High",
	PDTC(0x0654), "Engine RPM Output Circuit",
	PDTC(0x0655), "Engine Hot Lamp Output Control Circuit",
	PDTC(0x0656), "Fuel Level Output Circuit",
	PDTC(0x0657), "Actuator Supply Voltage 'A' Circuit",
	PDTC(0x0658), "Actuator Supply Voltage 'A' Circuit Low",
	PDTC(0x0659), "Actuator Supply Voltage 'A' Circuit High",
	PDTC(0x0660), "Intake Man. Tuning Valve Control Circuit (B1)",
	PDTC(0x0661), "Intake Man. Tuning Valve Control Circuit Low (B1)",
	PDTC(0x0662), "Intake Man. Tuning Valve Control Circuit High (B1)",
	PDTC(0x0663), "Intake Man. Tuning Valve Control Circuit (B2)",
	PDTC(0x0664), "Intake Man. Tuning Valve Control Circuit Low (B2)",
	PDTC(0x0665), "Intake Man. Tuning Valve Control Circuit High (B2)",
	PDTC(0x0666), "ECM/PCM/TCM Internal Temp. Sensor Circuit",
	PDTC(0x0667), "ECM/PCM/TCM Internal Temp. Sensor Range/Perf.",
	PDTC(0x0668), "ECM/PCM/TCM Internal Temp. Sensor Circuit Low",
	PDTC(0x0669), "ECM/PCM/TCM Internal Temp. Sensor Circuit High",
	PDTC(0x0670), "Glow Plug Module Control Circuit",
	PDTC(0x0671), "Cylinder 1 Glow Plug Circuit",
	PDTC(0x0672), "Cylinder 2 Glow Plug Circuit",
	PDTC(0x0673), "Cylinder 3 Glow Plug Circuit",
	PDTC(0x0674), "Cylinder 4 Glow Plug Circuit",
	PDTC(0x0675), "Cylinder 5 Glow Plug Circuit",
	PDTC(0x0676), "Cylinder 6 Glow Plug Circuit",
	PDTC(0x0677), "Cylinder 7 Glow Plug Circuit",
	PDTC(0x0678), "Cylinder 8 Glow Plug Circuit",
	PDTC(0x0679), "Cylinder 9 Glow Plug Circuit",
	PDTC(0x0680), "Cylinder 10 Glow Plug Circuit",
	PDTC(0x0681), "Cylinder 11 Glow Plug Circuit",
	PDTC(0x0682), "Cylinder 12 Glow Plug Circuit",
	PDTC(0x0683), "Glow Plug Control Module to PCM Comm. Circuit",
	PDTC(0x0684), "Glow Plug Control Module to PCM Comm. Circuit Range/Perf.",
	PDTC(0x0685), "ECM/PCM Power Relay Control Circuit",
	PDTC(0x0686), "ECM/PCM Power Relay Control Circuit Low",
	PDTC(0x0687), "ECM/PCM Power Relay Control Circuit High",
	PDTC(0x0688), "ECM/PCM Power Relay Sense Circuit",
	PDTC(0x0689), "ECM/PCM Power Relay Sense Circuit Low",
	PDTC(0x0690), "ECM/PCM Power Relay Sense Circuit High",
	PDTC(0x0691), "Fan 1 Control Circuit Low",
	PDTC(0x0692), "Fan 1 Control Circuit High",
	PDTC(0x0693), "Fan 2 Control Circuit Low",
	PDTC(0x0694), "Fan 2 Control Circuit High",
	PDTC(0x0695), "Fan 3 Control Circuit Low",
	PDTC(0x0696), "Fan 3 Control Circuit High",
	PDTC(0x0697), "Sensor Reference Voltage 'C' Circuit",
	PDTC(0x0698), "Sensor Reference Voltage 'C' Circuit Low",
	PDTC(0x0699), "Sensor Reference Voltage 'C' Circuit High",
	PDTC(0x0700), "Trans. Control System (MIL Request)",
	PDTC(0x0701), "Trans. Control System Range/Perf.",
	PDTC(0x0702), "Trans. Control System Electric",
	PDTC(0x0703), "Brake Switch 'B' Circuit",
	PDTC(0x0704), "Clutch Switch Input Circuit Malfunction",
	PDTC(0x0705), "Trans. Range Sensor Circuit Malfunction (PRNDL Input)",
	PDTC(0x0706), "Trans. Range Sensor Circuit Range/Perf.",
	PDTC(0x0707), "Trans. Range Sensor Circuit Low",
	PDTC(0x0708), "Trans. Range Sensor Circuit High",
	PDTC(0x0709), "Trans. Range Sensor Circuit Intermit.",
	PDTC(0x0710), "Trans. Fluid Temp. Sensor 'A' Circuit",
	PDTC(0x0711), "Trans. Fluid Temp. Sensor 'A' Circuit Range/Perf.",
	PDTC(0x0712), "Trans. Fluid Temp. Sensor 'A' Circuit Low",
	PDTC(0x0713), "Trans. Fluid Temp. Sensor 'A' Circuit High",
	PDTC(0x0714), "Trans. Fluid Temp. Sensor 'A' Circuit Intermit.",
	PDTC(0x0715), "Input/Turbine Speed Sensor 'A' Circuit",
	PDTC(0x0716), "Input/Turbine Speed Sensor 'A' Circuit Range/Perf.",
	PDTC(0x0717), "Input/Turbine Speed Sensor 'A' Circuit No Signal",
	PDTC(0x0718), "Input/Turbine Speed Sensor 'A' Circuit Intermit.",
	PDTC(0x0719), "Break Switch 'B' Circuit Low",
	PDTC(0x0720), "Output Speed Sensor Circuit",
	PDTC(0x0721), "Output Speed Sensor Circuit Range/Perf.",
	PDTC(0x0722), "Output Speed Sensor Circuit No Signal",
	PDTC(0x0723), "Output Speed Sensor Circuit No Intermit.",
	PDTC(0x0724), "Brake Switch 'B' Circuit High",
	PDTC(0x0725), "Engine Speed Input Circuit",
	PDTC(0x0726), "Engine Speed Input Circuit Range/Perf.",
	PDTC(0x0727), "Engine Speed Input Circuit No Signal",
	PDTC(0x0728), "Engine Speed Input Circuit Intermit.",
	PDTC(0x0729), "Gear 6 Incorrect Ratio",
	PDTC(0x0730), "Incorrect Gear Ratio",
	PDTC(0x0731), "Gear 1 Incorrect Ratio",
	PDTC(0x0732), "Gear 2 Incorrect Ratio",
	PDTC(0x0733), "Gear 3 Incorrect Ratio",
	PDTC(0x0734), "Gear 4 Incorrect Ratio",
	PDTC(0x0735), "Gear 5 Incorrect Ratio",
	PDTC(0x0736), "Reverse Incorrect Ratio",
	PDTC(0x0737), "TCM Engine Speed Output Circuit",
	PDTC(0x0738), "TCM Engine Speed Output Circuit Low",
	PDTC(0x0739), "TCM Engine Speed Output Circuit High",
	PDTC(0x0740), "Torque Converter Clutch Circuit",
	PDTC(0x0741), "Torque Converter Clutch Circuit Perf. or Stuck Off",
	PDTC(0x0742), "Torque Converter Clutch Circuit Stuck On",
	PDTC(0x0743), "Torque Converter Clutch Circuit Electric",
	PDTC(0x0744), "Torque Converter Clutch Circuit Intermit.",
	PDTC(0x0745), "Pres. Control Sol. 'A'",
	PDTC(0x0746), "Pres. Control Sol. 'A' Perf. or Stuck Off",
	PDTC(0x0747), "Pres. Control Sol. 'A' Stuck On",
	PDTC(0x0748), "Pres. Control Sol. 'A' Electrical",
	PDTC(0x0749), "Pres. Control Sol. 'A' Intermit.",
	PDTC(0x0750), "Shift Sol. 'A'",
	PDTC(0x0751), "Shift Sol. 'A' Perf. or Stuck Off",
	PDTC(0x0752), "Shift Sol. 'A' Stuck On",
	PDTC(0x0753), "Shift Sol. 'A' Electrical",
	PDTC(0x0754), "Shift Sol. 'A' Intermit.",
	PDTC(0x0755), "Shift Sol. 'B'",
	PDTC(0x0756), "Shift Sol. 'B' Perf. or Stuck Off",
	PDTC(0x0757), "Shift Sol. 'B' Stuck On",
	PDTC(0x0758), "Shift Sol. 'B' Electrical",
	PDTC(0x0759), "Shift Sol. 'B' Intermit.",
	PDTC(0x0760), "Shift Sol. 'C'",
	PDTC(0x0761), "Shift Sol. 'C' Perf. or Stuck Off",
	PDTC(0x0762), "Shift Sol. 'C' Stuck On",
	PDTC(0x0763), "Shift Sol. 'C' Electrical",
	PDTC(0x0764), "Shift Sol. 'C' Intermit.",
	PDTC(0x0765), "Shift Sol. 'D'",
	PDTC(0x0766), "Shift Sol. 'D' Perf. or Stuck Off",
	PDTC(0x0767), "Shift Sol. 'D' Stuck On",
	PDTC(0x0768), "Shift Sol. 'D' Electrical",
	PDTC(0x0769), "Shift Sol. 'D' Intermit.",
	PDTC(0x0770), "Shift Sol. 'E'",
	PDTC(0x0771), "Shift Sol. 'E' Perf. or Stuck Off",
	PDTC(0x0772), "Shift Sol. 'E' Stuck On",
	PDTC(0x0773), "Shift Sol. 'E' Electrical",
	PDTC(0x0774), "Shift Sol. 'E' Intermit.",
	PDTC(0x0775), "Pres. Control Sol. 'B'",
	PDTC(0x0776), "Pres. Control Sol. 'B' Perf. or Stuck Off",
	PDTC(0x0777), "Pres. Control Sol. 'B' Stuck On",
	PDTC(0x0778), "Pres. Control Sol. 'B' Electrical",
	PDTC(0x0779), "Pres. Control Sol. 'B' Intermit.",
	PDTC(0x0780), "Shift Error",
	PDTC(0x0781), "1-2 Shift",
	PDTC(0x0782), "2-3 Shift",
	PDTC(0x0783), "3-4 Shift",
	PDTC(0x0784), "4-5 Shift",
	PDTC(0x0785), "Shift/Timing Sol.",
	PDTC(0x0786), "Shift/Timing Sol. Range Perf.",
	PDTC(0x0787), "Shift/Timing Sol. Low",
	PDTC(0x0788), "Shift/Timing Sol. High",
	PDTC(0x0789), "Shift/Timing Sol. Intermit.",
	PDTC(0x0790), "Normal/Perf. Switch Circuit",
	PDTC(0x0791), "Interm. Shaft Speed Sensor 'A' Circuit",
	PDTC(0x0792), "Interm. Shaft Speed Sensor 'A' Circuit Range/Perf.",
	PDTC(0x0793), "Interm. Shaft Speed Sensor 'A' Circuit No Signal",
	PDTC(0x0794), "Interm. Shaft Speed Sensor 'A' Circuit Intermit.",
	PDTC(0x0795), "Pres. Control Sol. 'C'",
	PDTC(0x0796), "Pres. Control Sol. 'C' Perf. or Stuck Off",
	PDTC(0x0797), "Pres. Control Sol. 'C' Stuck On",
	PDTC(0x0798), "Pres. Control Sol. 'C' Electrical",
	PDTC(0x0799), "Pres. Control Sol. 'C' Intermit.",
	PDTC(0x0800), "Transfer Case Control System (MIL Request)",
	PDTC(0x0801), "Reverse Inhibit Control Circuit",
	PDTC(0x0802), "Trans. Control System MIL Request Circuit",
	PDTC(0x0803), "1-4 Upshift (Skip Shift) Sol. Control Circuit",
	PDTC(0x0804), "1-4 Upshift (Skip Shift) Lamp Control Circuit",
	PDTC(0x0805), "Clutch Position Sensor Circuit",
	PDTC(0x0806), "Clutch Position Sensor Circuit Range/Perf.",
	PDTC(0x0807), "Clutch Position Sensor Circuit Low",
	PDTC(0x0808), "Clutch Position Sensor Circuit High",
	PDTC(0x0809), "Clutch Position Sensor Circuit Intermit.",
	PDTC(0x0810), "Clutch Position Control Error",
	PDTC(0x0811), "Excessive Clutch Slippage",
	PDTC(0x0812), "Reverse Input Circuit",
	PDTC(0x0813), "Reverse Output Circuit",
	PDTC(0x0814), "Trans. Range Display Circuit",
	PDTC(0x0815), "Upshift Switch Circuit",
	PDTC(0x0816), "Downshift Switch Circuit",
	PDTC(0x0817), "Starter Disable Circuit",
	PDTC(0x0818), "Driveline Disconnect Switch Input Circuit",
	PDTC(0x0819), "Up and Down Shift Switch to Trans. Range Correlation",
	PDTC(0x0820), "Gear Lever X-Y Position Sensor Circuit",
	PDTC(0x0821), "Gear Lever X Position Circuit",
	PDTC(0x0822), "Gear Lever Y Position Circuit",
	PDTC(0x0823), "Gear Lever X Position Circuit Intermit.",
	PDTC(0x0824), "Gear Lever Y Position Circuit Intermit.",
	PDTC(0x0825), "Gear Lever Push-Pull Switch (Shift Anticipate)",
	PDTC(0x0826), "Up and Down Switch Shift Circuit",
	PDTC(0x0827), "Up and Down Switch Shift Circuit Low",
	PDTC(0x0828), "Up and Down Switch Shift Circuit High",
	PDTC(0x0829), "5-6 Shift",
	PDTC(0x0830), "Clutch Pedal Switch 'A' Circuit",
	PDTC(0x0831), "Clutch Pedal Switch 'A' Circuit Low",
	PDTC(0x0832), "Clutch Pedal Switch 'A' Circuit High",
	PDTC(0x0833), "Clutch Pedal Switch 'B' Circuit",
	PDTC(0x0834), "Clutch Pedal Switch 'B' Circuit Low",
	PDTC(0x0835), "Clutch Pedal Switch 'B' Circuit High",
	PDTC(0x0836), "Four Wheel Drive (4WD) Switch Circuit",
	PDTC(0x0837), "Four Wheel Drive (4WD) Switch Circuit Range/Perf.",
	PDTC(0x0838), "Four Wheel Drive (4WD) Switch Circuit Low",
	PDTC(0x0839), "Four Wheel Drive (4WD) Switch Circuit High",
	PDTC(0x0840), "Trans. Fluid Pres. Sensor/Switch 'A' Circuit",
	PDTC(0x0841), "Trans. Fluid Pres. Sensor/Switch 'A' Circuit Range/Perf.",
	PDTC(0x0842), "Trans. Fluid Pres. Sensor/Switch 'A' Circuit Low",
	PDTC(0x0843), "Trans. Fluid Pres. Sensor/Switch 'A' Circuit High",
	PDTC(0x0844), "Trans. Fluid Pres. Sensor/Switch 'A' Intermit.",
	PDTC(0x0845), "Trans. Fluid Pres. Sensor/Switch 'B' Circuit",
	PDTC(0x0846), "Trans. Fluid Pres. Sensor/Switch 'B' Circuit Range/Perf.",
	PDTC(0x0847), "Trans. Fluid Pres. Sensor/Switch 'B' Circuit Low",
	PDTC(0x0848), "Trans. Fluid Pres. Sensor/Switch 'B' Circuit High",
	PDTC(0x0849), "Trans. Fluid Pres. Sensor/Switch 'B' Intermit.",
	PDTC(0x0850), "Park/Neutral Switch Input Circuit",
	PDTC(0x0851), "Park/Neutral Switch Input Circuit Low",
	PDTC(0x0852), "Park/Neutral Switch Input Circuit High",
	PDTC(0x0853), "Drive Switch Input Circuit",
	PDTC(0x0854), "Drive Switch Input Circuit Low",
	PDTC(0x0855), "Drive Switch Input Circuit High",
	PDTC(0x0856), "Traction Control Input Signal",
	PDTC(0x0857), "Traction Control Input Signal Range/Perf.",
	PDTC(0x0858), "Traction Control Input Signal Low",
	PDTC(0x0859), "Traction Control Input Signal High",
	PDTC(0x0860), "Gear Shift Module Comm. Circuit",
	PDTC(0x0861), "Gear Shift Module Comm. Circuit Low",
	PDTC(0x0862), "Gear Shift Module Comm. Circuit High",
	PDTC(0x0863), "TCM Comm. Circuit",
	PDTC(0x0864), "TCM Comm. Circuit Range/Perf.",
	PDTC(0x0865), "TCM Comm. Circuit Low",
	PDTC(0x0866), "TCM Comm. Circuit High",
	PDTC(0x0867), "Trans. Fluid Pres.",
	PDTC(0x0868), "Trans. Fluid Pres. Low",
	PDTC(0x0869), "Trans. Fluid Pres. High",
	PDTC(0x0870), "Trans. Fluid Pres. Sensor/Switch 'C' Circuit",
	PDTC(0x0871), "Trans. Fluid Pres. Sensor/Switch 'C' Circuit Range/Perf.",
	PDTC(0x0872), "Trans. Fluid Pres. Sensor/Switch 'C' Circuit Low",
	PDTC(0x0873), "Trans. Fluid Pres. Sensor/Switch 'C' Circuit High",
	PDTC(0x0874), "Trans. Fluid Pres. Sensor/Switch 'C' Circuit Intermit.",
	PDTC(0x0875), "Trans. Fluid Pres. Sensor/Switch 'D' Circuit",
	PDTC(0x0876), "Trans. Fluid Pres. Sensor/Switch 'D' Circuit Range/Perf.",
	PDTC(0x0877), "Trans. Fluid Pres. Sensor/Switch 'D' Circuit Low",
	PDTC(0x0878), "Trans. Fluid Pres. Sensor/Switch 'D' Circuit High",
	PDTC(0x0879), "Trans. Fluid Pres. Sensor/Switch 'D' Circuit Intermit.",
	PDTC(0x0880), "TCM Power Input Signal",
	PDTC(0x0881), "TCM Power Input Signal Range/Perf.",
	PDTC(0x0882), "TCM Power Input Signal Low",
	PDTC(0x0883), "TCM Power Input Signal High",
	PDTC(0x0884), "TCM Power Input Signal Intermit.",
	PDTC(0x0885), "TCM Power Relay Control Circuit",
	PDTC(0x0886), "TCM Power Relay Control Circuit Low",
	PDTC(0x0887), "TCM Power Relay Control Circuit High",
	PDTC(0x0888), "TCM Power Relay Sense Circuit",
	PDTC(0x0889), "TCM Power Relay Sense Circuit Range/Perf.",
	PDTC(0x0890), "TCM Power Relay Sense Circuit Low",
	PDTC(0x0891), "TCM Power Relay Sense Circuit High",
	PDTC(0x0892), "TCM Power Relay Sense Circuit Intermit.",
	PDTC(0x0893), "Multiple Gears Engaged",
	PDTC(0x0894), "Trans. Component Slipping",
	PDTC(0x0895), "Shift Times Too Short",
	PDTC(0x0896), "Shift Times Too Long",
	PDTC(0x0897), "Trans. Fluid Deteriorated",
	PDTC(0x0898), "Trans. Control System MIL Request Circuit Low",
	PDTC(0x0899), "Trans. Control System MIL Request Circuit High",
	PDTC(0x0900), "Clutch Actuator Circuit",
	PDTC(0x0901), "Clutch Actuator Circuit Range/Perf.",
	PDTC(0x0902), "Clutch Actuator Circuit Low",
	PDTC(0x0903), "Clutch Actuator Circuit High",
	PDTC(0x0904), "Gate Select Position Circuit",
	PDTC(0x0905), "Gate Select Position Circuit Range/Perf.",
	PDTC(0x0906), "Gate Select Position Circuit Low",
	PDTC(0x0907), "Gate Select Position Circuit High",
	PDTC(0x0908), "Gate Select Position Circuit Intermit.",
	PDTC(0x0909), "Gate Select Control Error",
	PDTC(0x0910), "Gate Select Actuator Circuit",
	PDTC(0x0911), "Gate Select Actuator Circuit Range/Perf.",
	PDTC(0x0912), "Gate Select Actuator Circuit Low",
	PDTC(0x0913), "Gate Select Actuator Circuit High",
	PDTC(0x0914), "Gear Shift Position Circuit",
	PDTC(0x0915), "Gear Shift Position Circuit Range/Perf.",
	PDTC(0x0916), "Gear Shift Position Circuit Low",
	PDTC(0x0917), "Gear Shift Position Circuit High",
	PDTC(0x0918), "Gear Shift Position Circuit Intermit.",
	PDTC(0x0919), "Gear Shift Position Control Error",
	PDTC(0x0920), "Gear Shift Forward Actuator Circuit",
	PDTC(0x0921), "Gear Shift Forward Actuator Circuit Range/Perf.",
	PDTC(0x0922), "Gear Shift Forward Actuator Circuit Low",
	PDTC(0x0923), "Gear Shift Forward Actuator Circuit High",
	PDTC(0x0924), "Gear Shift Reverse Actuator Circuit",
	PDTC(0x0925), "Gear Shift Reverse Actuator Circuit Range/Perf.",
	PDTC(0x0926), "Gear Shift Reverse Actuator Circuit Low",
	PDTC(0x0927), "Gear Shift Reverse Actuator Circuit High",
	PDTC(0x0928), "Gear Shift Lock Sol. Control Circuit",
	PDTC(0x0929), "Gear Shift Lock Sol. Control Circuit Range/Perf.",
	PDTC(0x0930), "Gear Shift Lock Sol. Control Circuit Low",
	PDTC(0x0931), "Gear Shift Lock Sol. Control Circuit High",
	PDTC(0x0932), "Hydraulic Pres. Sensor Circuit",
	PDTC(0x0933), "Hydraulic Pres. Sensor Circuit Range/Perf.",
	PDTC(0x0934), "Hydraulic Pres. Sensor Circuit Low",
	PDTC(0x0935), "Hydraulic Pres. Sensor Circuit High",
	PDTC(0x0936), "Hydraulic Pres. Sensor Circuit Intermit.",
	PDTC(0x0937), "Hydraulic Oil Temp. Sensor Circuit",
	PDTC(0x0938), "Hydraulic Oil Temp. Sensor Circuit Range/Perf.",
	PDTC(0x0939), "Hydraulic Oil Temp. Sensor Circuit Low",
	PDTC(0x0940), "Hydraulic Oil Temp. Sensor Circuit High",
	PDTC(0x0941), "Hydraulic Oil Temp. Sensor Circuit Intermit.",
	PDTC(0x0942), "Hydraulic Pres. Unit",
	PDTC(0x0943), "Hydraulic Pres. Unit Cycling Period Too Short",
	PDTC(0x0944), "Hydraulic Pres. Unit Loss of Pres.",
	PDTC(0x0945), "Hydraulic Pump Relay Circuit",
	PDTC(0x0946), "Hydraulic Pump Relay Circuit Range/Perf.",
	PDTC(0x0947), "Hydraulic Pump Relay Circuit Low",
	PDTC(0x0948), "Hydraulic Pump Relay Circuit High",
	PDTC(0x0949), "Auto Shift Manual Adaptive Learning Not Complete",
	PDTC(0x0950), "Auto Shift Manual Control Circuit",
	PDTC(0x0951), "Auto Shift Manual Control Circuit Range/Perf.",
	PDTC(0x0952), "Auto Shift Manual Control Circuit Low",
	PDTC(0x0953), "Auto Shift Manual Control Circuit High",
	PDTC(0x0954), "Auto Shift Manual Control Circuit Intermit.",
	PDTC(0x0955), "Auto Shift Manual Mode Circuit",
	PDTC(0x0956), "Auto Shift Manual Mode Circuit Range/Perf.",
	PDTC(0x0957), "Auto Shift Manual Mode Circuit Low",
	PDTC(0x0958), "Auto Shift Manual Mode Circuit High",
	PDTC(0x0959), "Auto Shift Manual Mode Circuit Intermit.",
	PDTC(0x0960), "Pres. Control Sol. 'A' Control Circuit",
	PDTC(0x0961), "Pres. Control Sol. 'A' Control Circuit Range/Perf.",
	PDTC(0x0962), "Pres. Control Sol. 'A' Control Circuit Low",
	PDTC(0x0963), "Pres. Control Sol. 'A' Control Circuit High",
	PDTC(0x0964), "Pres. Control Sol. 'B' Control Circuit",
	PDTC(0x0965), "Pres. Control Sol. 'B' Control Circuit Range/Perf.",
	PDTC(0x0966), "Pres. Control Sol. 'B' Control Circuit Low",
	PDTC(0x0967), "Pres. Control Sol. 'B' Control Circuit High",
	PDTC(0x0968), "Pres. Control Sol. 'C' Control Circuit",
	PDTC(0x0969), "Pres. Control Sol. 'C' Control Circuit Range/Perf.",
	PDTC(0x0970), "Pres. Control Sol. 'C' Control Circuit Low",
	PDTC(0x0971), "Pres. Control Sol. 'C' Control Circuit High",
	PDTC(0x0972), "Shift Sol. 'A' Control Circuit Range/Perf.",
	PDTC(0x0973), "Shift Sol. 'A' Control Circuit Low",
	PDTC(0x0974), "Shift Sol. 'A' Control Circuit High",
	PDTC(0x0975), "Shift Sol. 'B' Control Circuit Range/Perf.",
	PDTC(0x0976), "Shift Sol. 'B' Control Circuit Low",
	PDTC(0x0977), "Shift Sol. 'B' Control Circuit High",
	PDTC(0x0978), "Shift Sol. 'C' Control Circuit Range/Perf.",
	PDTC(0x0979), "Shift Sol. 'C' Control Circuit Low",
	PDTC(0x0980), "Shift Sol. 'C' Control Circuit High",
	PDTC(0x0981), "Shift Sol. 'D' Control Circuit Range/Perf.",
	PDTC(0x0982), "Shift Sol. 'D' Control Circuit Low",
	PDTC(0x0983), "Shift Sol. 'D' Control Circuit High",
	PDTC(0x0984), "Shift Sol. 'E' Control Circuit Range/Perf.",
	PDTC(0x0985), "Shift Sol. 'E' Control Circuit Low",
	PDTC(0x0986), "Shift Sol. 'E' Control Circuit High",
	PDTC(0x0987), "Trans. Fluid Pres. Sensor/Switch 'E' Circuit",
	PDTC(0x0988), "Trans. Fluid Pres. Sensor/Switch 'E' Circuit Range/Perf.",
	PDTC(0x0989), "Trans. Fluid Pres. Sensor/Switch 'E' Circuit Low",
	PDTC(0x0990), "Trans. Fluid Pres. Sensor/Switch 'E' Circuit High",
	PDTC(0x0991), "Trans. Fluid Pres. Sensor/Switch 'E' Circuit Intermit.",
	PDTC(0x0992), "Trans. Fluid Pres. Sensor/Switch 'F' Circuit",
	PDTC(0x0993), "Trans. Fluid Pres. Sensor/Switch 'F' Circuit Range/Perf.",
	PDTC(0x0994), "Trans. Fluid Pres. Sensor/Switch 'F' Circuit Low",
	PDTC(0x0995), "Trans. Fluid Pres. Sensor/Switch 'F' Circuit High",
	PDTC(0x0996), "Trans. Fluid Pres. Sensor/Switch 'F' Circuit Intermit.",
	PDTC(0x0997), "Shift Sol. 'F' Control Circuit Range/Perf.",
	PDTC(0x0998), "Shift Sol. 'F' Control Circuit Low",
	PDTC(0x0999), "Shift Sol. 'F' Control Circuit High",
	PDTC(0x0A00), "Motor Electronics Coolant Temp. Sensor Circuit",
	PDTC(0x0A01), "Motor Electronics Coolant Temp. Sensor Circuit Range/Perf.",
	PDTC(0x0A02), "Motor Electronics Coolant Temp. Sensor Circuit Low",
	PDTC(0x0A03), "Motor Electronics Coolant Temp. Sensor Circuit High",
	PDTC(0x0A04), "Motor Electronics Coolant Temp. Sensor Circuit Intermit.",
	PDTC(0x0A05), "Motor Electronics Coolant Pump Control Circuit",
	PDTC(0x0A06), "Motor Electronics Coolant Pump Control Circuit Low",
	PDTC(0x0A07), "Motor Electronics Coolant Pump Control Circuit High",
	PDTC(0x0A08), "DC/DC Converter Status Circuit",
	PDTC(0x0A09), "DC/DC Converter Status Circuit Low Input",
	PDTC(0x0A10), "DC/DC Converter Status Circuit High Input",
	PDTC(0x0A11), "DC/DC Converter Enable Circuit",
	PDTC(0x0A12), "DC/DC Converter Enable Circuit Low",
	PDTC(0x0A13), "DC/DC Converter Enable Circuit High",
	PDTC(0x0A14), "Engine Mount Control Circuit",
	PDTC(0x0A15), "Engine Mount Control Circuit Low",
	PDTC(0x0A16), "Engine Mount Control Circuit High",
	PDTC(0x0A17), "Motor Torque Sensor Circuit",
	PDTC(0x0A18), "Motor Torque Sensor Circuit Range/Perf.",
	PDTC(0x0A19), "Motor Torque Sensor Circuit Low",
	PDTC(0x0A20), "Motor Torque Sensor Circuit High",
	PDTC(0x0A21), "Motor Torque Sensor Circuit Intermit.",
	PDTC(0x0A22), "Generator Torque Sensor Circuit",
	PDTC(0x0A23), "Generator Torque Sensor Circuit Range/Perf.",
	PDTC(0x0A24), "Generator Torque Sensor Circuit Low",
	PDTC(0x0A25), "Generator Torque Sensor Circuit High",
	PDTC(0x0A26), "Generator Torque Sensor Circuit Intermit.",
	PDTC(0x0A27), "Battery Power Off Circuit",
	PDTC(0x0A28), "Battery Power Off Circuit Low",
	PDTC(0x0A29), "Battery Power Off Circuit High",
	PDTC(0x2000), "NOx Trap Efficiency Below Threshold (B1)",
	PDTC(0x2001), "NOx Trap Efficiency Below Threshold (B2)",
	PDTC(0x2002), "Particulate Trap Efficiency Below Threshold (B1)",
	PDTC(0x2003), "Particulate Trap Efficiency Below Threshold (B2)",
	PDTC(0x2004), "Intake Man. Runner Control Stuck Open (B1)",
	PDTC(0x2005), "Intake Man. Runner Control Stuck Open (B2)",
	PDTC(0x2006), "Intake Man. Runner Control Stuck Closed (B1)",
	PDTC(0x2007), "Intake Man. Runner Control Stuck Closed (B2)",
	PDTC(0x2008), "Intake Man. Runner Control Circuit (B1)",
	PDTC(0x2009), "Intake Man. Runner Control Circuit Low (B1)",
	PDTC(0x2010), "Intake Man. Runner Control Circuit High (B1)",
	PDTC(0x2011), "Intake Man. Runner Control Circuit (B2)",
	PDTC(0x2012), "Intake Man. Runner Control Circuit Low (B2)",
	PDTC(0x2013), "Intake Man. Runner Control Circuit High (B2)",
	PDTC(0x2014), "Intake Man. Runner Position Sensor/Switch Circuit (B1)",
	PDTC(0x2015), "Intake Man. Runner Pos. Sensor/Switch Circuit Range/Perf. (B1)",
	PDTC(0x2016), "Intake Man. Runner Pos. Sensor/Switch Circuit Low (B1)",
	PDTC(0x2017), "Intake Man. Runner Pos. Sensor/Switch Circuit High (B1)",
	PDTC(0x2018), "Intake Man. Runner Pos. Sensor/Switch Circuit Intermit. (B1)",
	PDTC(0x2019), "Intake Man. Runner Pos. Sensor/Switch Circuit (B2) (B1)",
	PDTC(0x2020), "Intake Man. Runner Pos. Sensor/Switch Circuit Range/Perf. (B2)",
	PDTC(0x2021), "Intake Man. Runner Pos. Sensor/Switch Circuit Low (B2)",
	PDTC(0x2022), "Intake Man. Runner Pos. Sensor/Switch Circuit High (B2)",
	PDTC(0x2023), "Intake Man. Runner Pos. Sensor/Switch Circuit Intermit. (B2)",
	PDTC(0x2024), "Evap. Emissions Fuel Vapor Temp. Sensor Circuit",
	PDTC(0x2025), "Evap. Emissions Fuel Vapor Temp. Sensor Perf.",
	PDTC(0x2026), "Evap. Emissions Fuel Vapor Temp. Sensor Circuit Low Volt.",
	PDTC(0x2027), "Evap. Emissions Fuel Vapor Temp. Sensor Circuit High Volt.",
	PDTC(0x2028), "Evap. Emissions Fuel Vapor Temp. Sensor Circuit Intermit.",
	PDTC(0x2029), "Fuel Fired Heater Disabled",
	PDTC(0x2030), "Fuel Fired Heater Perf.",
	PDTC(0x2031), "Exhaust Gas Temp. Sensor Circuit (B1-S2)",
	PDTC(0x2032), "Exhaust Gas Temp. Sensor Circuit Low (B1-S2)",
	PDTC(0x2033), "Exhaust Gas Temp. Sensor Circuit High (B1-S2)",
	PDTC(0x2034), "Exhaust Gas Temp. Sensor Circuit (B2-S2)",
	PDTC(0x2035), "Exhaust Gas Temp. Sensor Circuit Low (B2-S2)",
	PDTC(0x2036), "Exhaust Gas Temp. Sensor Circuit High (B2-S2)",
	PDTC(0x2037), "Reductant Inj. Air Pres. Sensor Circuit",
	PDTC(0x2038), "Reductant Inj. Air Pres. Sensor Circuit Range/Perf.",
	PDTC(0x2039), "Reductant Inj. Air Pres. Sensor Circuit Low Input",
	PDTC(0x2040), "Reductant Inj. Air Pres. Sensor Circuit High Input",
	PDTC(0x2041), "Reductant Inj. Air Pres. Sensor Circuit Intermit.",
	PDTC(0x2042), "Reductant Temp. Sensor Circuit",
	PDTC(0x2043), "Reductant Temp. Sensor Circuit Range/Perf.",
	PDTC(0x2044), "Reductant Temp. Sensor Circuit Low Input",
	PDTC(0x2045), "Reductant Temp. Sensor Circuit High Input",
	PDTC(0x2046), "Reductant Temp. Sensor Circuit Intermit.",
	PDTC(0x2047), "Reductant Injector Circuit (B1-U1)",
	PDTC(0x2048), "Reductant Injector Circuit Low (B1-U1)",
	PDTC(0x2049), "Reductant Injector Circuit High (B1-U1)",
	PDTC(0x2050), "Reductant Injector Circuit (B2-U1)",
	PDTC(0x2051), "Reductant Injector Circuit Low (B2-U1)",
	PDTC(0x2052), "Reductant Injector Circuit High (B2-U1)",
	PDTC(0x2053), "Reductant Injector Circuit (B1-U2)",
	PDTC(0x2054), "Reductant Injector Circuit Low (B1-U2)",
	PDTC(0x2055), "Reductant Injector Circuit High (B1-U2)",
	PDTC(0x2056), "Reductant Injector Circuit (B2-U2)",
	PDTC(0x2057), "Reductant Injector Circuit Low (B2-U2)",
	PDTC(0x2058), "Reductant Injector Circuit High (B2-U2)",
	PDTC(0x2059), "Reductant Injector Air Pump Control Circuit",
	PDTC(0x2060), "Reductant Injector Air Pump Control Circuit Low",
	PDTC(0x2061), "Reductant Injector Air Pump Control Circuit High",
	PDTC(0x2062), "Reductant Supply Control Circuit",
	PDTC(0x2063), "Reductant Supply Control Circuit Low",
	PDTC(0x2064), "Reductant Supply Control Circuit High",
	PDTC(0x2065), "Fuel Level Sensor 'B' Circuit",
	PDTC(0x2066), "Fuel Level Sensor 'B' Perf.",
	PDTC(0x2067), "Fuel Level Sensor 'B' Circuit Low",
	PDTC(0x2068), "Fuel Level Sensor 'B' Circuit High",
	PDTC(0x2069), "Fuel Level Sensor 'B' Circuit Intermit.",
	PDTC(0x2070), "Intake Man. Tuning Valve Stuck Open",
	PDTC(0x2071), "Intake Man. Tuning Valve Stuck Closed",
	PDTC(0x2075), "Intake Man. Tuning Valve Pos. Sens/Sw Circuit",
	PDTC(0x2076), "Intake Man. Tuning Valve Pos. Sens/Sw Circuit Range/Perf.",
	PDTC(0x2077), "Intake Man. Tuning Valve Pos. Sens/Sw Circuit Low",
	PDTC(0x2078), "Intake Man. Tuning Valve Pos. Sens/Sw Circuit High",
	PDTC(0x2079), "Intake Man. Tuning Valve Pos. Sens/Sw Circuit Intermit.",
	PDTC(0x2080), "Exhaust Gas Temp. Sensor Circuit Range/Perf. (B1-S1)",
	PDTC(0x2081), "Exhaust Gas Temp. Sensor Circuit Intermit. (B1-S1)",
	PDTC(0x2082), "Exhaust Gas Temp. Sensor Circuit Range/Perf. (B2-S1)",
	PDTC(0x2083), "Exhaust Gas Temp. Sensor Circuit Intermit. (B2-S1)",
	PDTC(0x2084), "Exhaust Gas Temp. Sensor Circuit Range/Perf. (B1-S2)",
	PDTC(0x2085), "Exhaust Gas Temp. Sensor Circuit Intermit. (B1-S2)",
	PDTC(0x2086), "Exhaust Gas Temp. Sensor Circuit Range/Perf. (B2-S2)",
	PDTC(0x2087), "Exhaust Gas Temp. Sensor Circuit Intermit. (B2-S2)",
	PDTC(0x2088), "'A' Camshaft Pos. Actuator Control Circuit Low (B1)",
	PDTC(0x2089), "'A' Camshaft Pos. Actuator Control Circuit High (B1)",
	PDTC(0x2090), "'B' Camshaft Pos. Actuator Control Circuit Low (B1)",
	PDTC(0x2091), "'B' Camshaft Pos. Actuator Control Circuit High (B1)",
	PDTC(0x2092), "'A' Camshaft Pos. Actuator Control Circuit Low (B2)",
	PDTC(0x2093), "'A' Camshaft Pos. Actuator Control Circuit High (B2)",
	PDTC(0x2094), "'B' Camshaft Pos. Actuator Control Circuit Low (B2)",
	PDTC(0x2095), "'B' Camshaft Pos. Actuator Control Circuit High (B2)",
	PDTC(0x2096), "Post Catalyst Fuel Trim System Too Lean (B1)",
	PDTC(0x2097), "Post Catalyst Fuel Trim System Too Rich (B1)",
	PDTC(0x2098), "Post Catalyst Fuel Trim System Too Lean (B2)",
	PDTC(0x2099), "Post Catalyst Fuel Trim System Too Rich (B2)",
	PDTC(0x2100), "Throttle Actuator Control Motor Circuit",
	PDTC(0x2101), "Throttle Actuator Control Motor Circuit Range/Perormance",
	PDTC(0x2102), "Throttle Actuator Control Motor Circuit Low",
	PDTC(0x2103), "Throttle Actuator Control Motor Circuit High",
	PDTC(0x2104), "Throttle Actuator Control System-Forced Idle",
	PDTC(0x2105), "Throttle Actuator Control System-Forced Engine Shutdown",
	PDTC(0x2106), "Throttle Actuator Control System-Forced Limited Power",
	PDTC(0x2107), "Throttle Actuator Control Module Processor",
	PDTC(0x2108), "Throttle Actuator Control Module Perf.",
	PDTC(0x2109), "Throttle Pos. Sensor 'A' Minimum Stop Perf.",
	PDTC(0x2110), "Throttle Actuator Control System-Forced Limited RPM",
	PDTC(0x2111), "Throttle Actuator Control System-Stuck Open",
	PDTC(0x2112), "Throttle Actuator Control System-Stuck Closed",
	PDTC(0x2113), "Throttle Pos. Sensor 'B' Minimum Stop Perf.",
	PDTC(0x2114), "Throttle Pos. Sensor 'C' Minimum Stop Perf.",
	PDTC(0x2115), "Throttle Pos. Sensor 'D' Minimum Stop Perf.",
	PDTC(0x2116), "Throttle Pos. Sensor 'E' Minimum Stop Perf.",
	PDTC(0x2117), "Throttle Pos. Sensor 'F' Minimum Stop Perf.",
	PDTC(0x2118), "Throttle Actuator Control Motor Current Range/Perf.",
	PDTC(0x2119), "Throttle Actuator Control Throttle Body Range/Perf.",
	PDTC(0x2120), "Throttle Pos. Sensor/Switch 'D' Circuit",
	PDTC(0x2121), "Throttle Pos. Sensor/Switch 'D' Circuit Range/Perf.",
	PDTC(0x2122), "Throttle Pos. Sensor/Switch 'D' Circuit Low Input",
	PDTC(0x2123), "Throttle Pos. Sensor/Switch 'D' Circuit High Imput",
	PDTC(0x2124), "Throttle Pos. Sensor/Switch 'D' Circuit Intermit.",
	PDTC(0x2125), "Throttle Pos. Sensor/Switch 'E' Circuit",
	PDTC(0x2126), "Throttle Pos. Sensor/Switch 'E' Circuit Range/Perf.",
	PDTC(0x2127), "Throttle Pos. Sensor/Switch 'E' Circuit Low Input",
	PDTC(0x2128), "Throttle Pos. Sensor/Switch 'E' Circuit High Imput",
	PDTC(0x2129), "Throttle Pos. Sensor/Switch 'E' Circuit Intermit.",
	PDTC(0x2130), "Throttle Pos. Sensor/Switch 'F' Circuit",
	PDTC(0x2131), "Throttle Pos. Sensor/Switch 'F' Circuit Range/Perf.",
	PDTC(0x2132), "Throttle Pos. Sensor/Switch 'F' Circuit Low Input",
	PDTC(0x2133), "Throttle Pos. Sensor/Switch 'F' Circuit High Imput",
	PDTC(0x2134), "Throttle Pos. Sensor/Switch 'F' Circuit Intermit.",
	PDTC(0x2135), "Throttle Pos. Sensor/Switch 'A'/'B' Voltage Correlation",
	PDTC(0x2136), "Throttle Pos. Sensor/Switch 'A'/'C' Voltage Correlation",
	PDTC(0x2137), "Throttle Pos. Sensor/Switch 'B'/'C' Voltage Correlation",
	PDTC(0x2138), "Throttle Pos. Sensor/Switch 'D'/'E' Voltage Correlation",
	PDTC(0x2139), "Throttle Pos. Sensor/Switch 'D'/'F' Voltage Correlation",
	PDTC(0x2140), "Throttle Pos. Sensor/Switch 'E'/'F' Voltage Correlation",
	PDTC(0x2141), "Exhaust Gas Recirculation Throttle Control Circuit Low",
	PDTC(0x2142), "Exhaust Gas Recirculation Throttle Control Circuit High",
	PDTC(0x2143), "Exhaust Gas Recirculation Vent Control Circuit",
	PDTC(0x2144), "Exhaust Gas Recirculation Vent Control Circuit Low",
	PDTC(0x2145), "Exhaust Gas Recirculation Vent Control Circuit High",
	PDTC(0x2146), "Fuel Injector Group 'A' Supple Voltage Circuit",
	PDTC(0x2147), "Fuel Injector Group 'A' Supple Voltage Circuit Low",
	PDTC(0x2148), "Fuel Injector Group 'A' Supple Voltage Circuit High",
	PDTC(0x2149), "Fuel Injector Group 'B' Supple Voltage Circuit",
	PDTC(0x2150), "Fuel Injector Group 'B' Supple Voltage Circuit Low",
	PDTC(0x2151), "Fuel Injector Group 'B' Supple Voltage Circuit High",
	PDTC(0x2152), "Fuel Injector Group 'C' Supple Voltage Circuit",
	PDTC(0x2153), "Fuel Injector Group 'C' Supple Voltage Circuit Low",
	PDTC(0x2154), "Fuel Injector Group 'C' Supple Voltage Circuit High",
	PDTC(0x2155), "Fuel Injector Group 'D' Supple Voltage Circuit",
	PDTC(0x2156), "Fuel Injector Group 'D' Supple Voltage Circuit Low",
	PDTC(0x2157), "Fuel Injector Group 'D' Supple Voltage Circuit High",
	PDTC(0x2158), "Vehicle Speed Sensor 'B'",
	PDTC(0x2159), "Vehicle Speed Sensor 'B' Range/Perf.",
	PDTC(0x2160), "Vehicle Speed Sensor 'B' Circuit Low",
	PDTC(0x2161), "Vehicle Speed Sensor 'B' Intermit.",
	PDTC(0x2162), "Vehicle Speed Sensor 'A'/'B' Correlation",
	PDTC(0x2163), "Throttle Pos. Sensor 'A' Maximum Stop Perf.",
	PDTC(0x2164), "Throttle Pos. Sensor 'B' Maximum Stop Perf.",
	PDTC(0x2165), "Throttle Pos. Sensor 'C' Maximum Stop Perf.",
	PDTC(0x2166), "Throttle Pos. Sensor 'D' Maximum Stop Perf.",
	PDTC(0x2167), "Throttle Pos. Sensor 'E' Maximum Stop Perf.",
	PDTC(0x2168), "Throttle Pos. Sensor 'F' Maximum Stop Perf.",
	PDTC(0x2169), "Exhaust Pres. Regulator Vent Sol. Control Circuit",
	PDTC(0x2170), "Exhaust Pres. Regulator Vent Sol. Control Circuit Low",
	PDTC(0x2171), "Exhaust Pres. Regulator Vent Sol. Control Circuit High",
	PDTC(0x2172), "Throttle Actuator Control System-Sudden High Airflow Detected",
	PDTC(0x2173), "Throttle Actuator Control System-High Airflow Detected",
	PDTC(0x2174), "Throttle Actuator Control System-Sudden Low Airflow Detected",
	PDTC(0x2175), "Throttle Actuator Control System-Low Airflow Detected",
	PDTC(0x2176), "Throttle Actuator Control System-Idle Pos. Not Learned",
	PDTC(0x2177), "System Too Lean Off Idle (B1)",
	PDTC(0x2178), "System Too Rich Off Idle (B1)",
	PDTC(0x2179), "System Too Lean Off Idle (B2)",
	PDTC(0x2180), "System Too Rich Off Idle (B2)",
	PDTC(0x2181), "Cooling System Perf.",
	PDTC(0x2182), "Engine Coolant Sensor 2 Circuit",
	PDTC(0x2183), "Engine Coolant Sensor 2 Circuit Range/Perf.",
	PDTC(0x2184), "Engine Coolant Sensor 2 Circuit Low",
	PDTC(0x2185), "Engine Coolant Sensor 2 Circuit High",
	PDTC(0x2186), "Engine Coolant Sensor 2 Circuit Intermit.",
	PDTC(0x2187), "System Too Lean at Idle (B1)",
	PDTC(0x2188), "System Too Rich at Idle (B1)",
	PDTC(0x2189), "System Too Lean at Idle (B2)",
	PDTC(0x2190), "System Too Rich at Idle (B2)",
	PDTC(0x2191), "System Too Lean at Higher Load (B1)",
	PDTC(0x2192), "System Too Rich at Higher Load (B1)",
	PDTC(0x2193), "System Too Lean at Higher Load (B2)",
	PDTC(0x2194), "System Too Rich at Higher Load (B2)",
	PDTC(0x2195), "O2 Sensor Signal Stuck Lean (B1-S1)",
	PDTC(0x2196), "O2 Sensor Signal Stuck Rich (B1-S1)",
	PDTC(0x2197), "O2 Sensor Signal Stuck Lean (B2-S1)",
	PDTC(0x2198), "O2 Sensor Signal Stuck Rich (B2-S1)",
	PDTC(0x2199), "Intake Air Temp. Sendor 1/2 Correlation",
	PDTC(0x2200), "NOx Sensor Circuit (B1)",
	PDTC(0x2201), "NOx Sensor Circuit Range/Perf. (B1)",
	PDTC(0x2202), "NOx Sensor Circuit Low Input (B1)",
	PDTC(0x2203), "NOx Sensor Circuit High Input (B1)",
	PDTC(0x2204), "NOx Sensor Circuit Intermit. Input (B1)",
	PDTC(0x2205), "NOx Sensor Heater Control Circuit (B1)",
	PDTC(0x2206), "NOx Sensor Heater Control Circuit Low (B1)",
	PDTC(0x2207), "NOx Sensor Heater Control Circuit High (B1)",
	PDTC(0x2208), "NOx Sensor Heater Sense Circuit (B1)",
	PDTC(0x2209), "NOx Sensor Heater Sense Circuit Range/Perf. (B1)",
	PDTC(0x2210), "NOx Sensor Heater Sense Circuit Low Input (B1)",
	PDTC(0x2211), "NOx Sensor Heater Sense Circuit High Input (B1)",
	PDTC(0x2212), "NOx Sensor Heater Sense Circuit Intermit. (B1)",
	PDTC(0x2213), "NOx Sensor Circuit (B2)",
	PDTC(0x2214), "NOx Sensor Circuit Range/Perf. (B2)",
	PDTC(0x2215), "NOx Sensor Circuit Low Input (B2)",
	PDTC(0x2216), "NOx Sensor Circuit High Input (B2)",
	PDTC(0x2217), "NOx Sensor Circuit Intermit. Input (B2)",
	PDTC(0x2218), "NOx Sensor Heater Control Circuit (B2)",
	PDTC(0x2219), "NOx Sensor Heater Control Circuit Low (B2)",
	PDTC(0x2220), "NOx Sensor Heater Control Circuit High (B2)",
	PDTC(0x2221), "NOx Sensor Heater Sense Circuit (B2)",
	PDTC(0x2222), "NOx Sensor Heater Sense Circuit Range/Perf. (B2)",
	PDTC(0x2223), "NOx Sensor Heater Sense Circuit Low (B2)",
	PDTC(0x2224), "NOx Sensor Heater Sense Circuit High (B2)",
	PDTC(0x2225), "NOx Sensor Heater Sense Circuit Intermit. (B2)",
	PDTC(0x2226), "Barometric Pres. Circuit",
	PDTC(0x2227), "Barometric Pres. Circuit Range/Perf.",
	PDTC(0x2228), "Barometric Pres. Circuit Low",
	PDTC(0x2229), "Barometric Pres. Circuit High",
	PDTC(0x2230), "Barometric Pres. Circuit Intermit.",
	PDTC(0x2231), "O2 Sensor Signal Circuit Shorted to Heater Circuit (B1-S1)",
	PDTC(0x2232), "O2 Sensor Signal Circuit Shorted to Heater Circuit (B1-S2)",
	PDTC(0x2233), "O2 Sensor Signal Circuit Shorted to Heater Circuit (B1-S3)",
	PDTC(0x2234), "O2 Sensor Signal Circuit Shorted to Heater Circuit (B2-S1)",
	PDTC(0x2235), "O2 Sensor Signal Circuit Shorted to Heater Circuit (B2-S2)",
	PDTC(0x2236), "O2 Sensor Signal Circuit Shorted to Heater Circuit (B2-S3)",
	PDTC(0x2237), "O2 Sensor Positive Current Control Circuit (B1-S1)",
	PDTC(0x2238), "O2 Sensor Positive Current Control Circuit Low (B1-S1)",
	PDTC(0x2239), "O2 Sensor Positive Current Control Circuit High (B1-S1)",
	PDTC(0x2240), "O2 Sensor Positive Current Control Circuit (B2-S1)",
	PDTC(0x2241), "O2 Sensor Positive Current Control Circuit Low (B2-S1)",
	PDTC(0x2242), "O2 Sensor Positive Current Control Circuit High (B2-S1)",
	PDTC(0x2243), "O2 Sensor Reference Voltage Circuit (B1-S1)",
	PDTC(0x2244), "O2 Sensor Reference Voltage Perf. (B1-S1)",
	PDTC(0x2245), "O2 Sensor Reference Voltage Circuit Low (B1-S1)",
	PDTC(0x2246), "O2 Sensor Reference Voltage Circuit High (B1-S1)",
	PDTC(0x2247), "O2 Sensor Reference Voltage Circuit (B2-S1)",
	PDTC(0x2248), "O2 Sensor Reference Voltage Perf. (B2-S1)",
	PDTC(0x2249), "O2 Sensor Reference Voltage Circuit Low (B2-S1)",
	PDTC(0x2250), "O2 Sensor Reference Voltage Circuit High (B2-S1)",
	PDTC(0x2251), "O2 Sensor Negative Current Control Circuit (B1-S1)",
	PDTC(0x2252), "O2 Sensor Negative Current Control Circuit Low (B1-S1)",
	PDTC(0x2253), "O2 Sensor Negative Current Control Circuit High (B1-S1)",
	PDTC(0x2254), "O2 Sensor Negative Current Control Circuit (B2-S1)",
	PDTC(0x2255), "O2 Sensor Negative Current Control Circuit Low (B2-S1)",
	PDTC(0x2256), "O2 Sensor Negative Current Control Circuit High (B2-S1)",
	PDTC(0x2257), "Sec. Air Inj. System Control 'A' Circuit Low",
	PDTC(0x2258), "Sec. Air Inj. System Control 'A' Circuit High",
	PDTC(0x2259), "Sec. Air Inj. System Control 'B' Circuit Low",
	PDTC(0x2260), "Sec. Air Inj. System Control 'B' Circuit High",
	PDTC(0x2261), "Turbo/Super Charger Bypass Valve - Mechanical",
	PDTC(0x2262), "Turbo Boost Pres. Not Detected - Mechanical",
	PDTC(0x2263), "Turbo/Super Charger Boost System Perf.",
	PDTC(0x2264), "Water in Fuel Sensor Circuit",
	PDTC(0x2265), "Water in Fuel Sensor Circuit Range/Perf.",
	PDTC(0x2266), "Water in Fuel Sensor Circuit Low",
	PDTC(0x2267), "Water in Fuel Sensor Circuit High",
	PDTC(0x2268), "Water in Fuel Sensor Circuit Intermit.",
	PDTC(0x2269), "Water in Fuel Condition",
	PDTC(0x2270), "O2 Sensor Signal Stuck Lean (B1-S2)",
	PDTC(0x2271), "O2 Sensor Signal Stuck Rich (B1-S2)",
	PDTC(0x2272), "O2 Sensor Signal Stuck Lean (B2-S2)",
	PDTC(0x2273), "O2 Sensor Signal Stuck Rich (B2-S2)",
	PDTC(0x2274), "O2 Sensor Signal Stuck Lean (B1-S3)",
	PDTC(0x2275), "O2 Sensor Signal Stuck Rich (B1-S3)",
	PDTC(0x2276), "O2 Sensor Signal Stuck Lean (B2-S3)",
	PDTC(0x2277), "O2 Sensor Signal Stuck Rich (B2-S3)",
	PDTC(0x2278), "O2 Sensor Signals Swapped B-1 S-3/ B-2 S-3",
	PDTC(0x2279), "Intake Air System Leak",
	PDTC(0x2280), "Air Flow Restriction/Air Leak Between Air Filter and MAF",
	PDTC(0x2281), "Air Leak Between MAF and Throttle Body",
	PDTC(0x2282), "Air Leak Between Throttle Body and Intake Valves",
	PDTC(0x2283), "Injector Control Pres. Sensor Circuit",
	PDTC(0x2284), "Injector Control Pres. Sensor Circuit Range/Perf.",
	PDTC(0x2285), "Injector Control Pres. Sensor Circuit Low",
	PDTC(0x2286), "Injector Control Pres. Sensor Circuit High",
	PDTC(0x2287), "Injector Control Pres. Sensor Circuit Intermit.",
	PDTC(0x2288), "Injector Control Pres. Too High",
	PDTC(0x2289), "Injector Control Pres. Too High - Engine Off",
	PDTC(0x2290), "Injector Control Pres. Too Low",
	PDTC(0x2291), "Injector Control Pres. Too Low - Engine Cranking",
	PDTC(0x2292), "Injector Control Pres. Erratic",
	PDTC(0x2293), "Fuel Pres. Regulator 2 Perf.",
	PDTC(0x2294), "Fuel Pres. Regulator 2 Control Circuit",
	PDTC(0x2295), "Fuel Pres. Regulator 2 Control Circuit Low",
	PDTC(0x2296), "Fuel Pres. Regulator 2 Control Circuit High",
	PDTC(0x2297), "O2 Sensor Out of Range During Deceleration (B1-S1)",
	PDTC(0x2298), "O2 Sensor Out of Range During Deceleration (B2-S1)",
	PDTC(0x2299), "Brake Pedal Pos. / Acc. Pedal Pos. Incompatible",
	PDTC(0x2300), "Ign. Coil 'A' Primary Control Circuit Low",
	PDTC(0x2301), "Ign. Coil 'A' Primary Control Circuit High",
	PDTC(0x2302), "Ign. Coil 'A' Secondary Control Circuit",
	PDTC(0x2303), "Ign. Coil 'B' Primary Control Circuit Low",
	PDTC(0x2304), "Ign. Coil 'B' Primary Control Circuit High",
	PDTC(0x2305), "Ign. Coil 'B' Secondary Control Circuit",
	PDTC(0x2306), "Ign. Coil 'C' Primary Control Circuit Low",
	PDTC(0x2307), "Ign. Coil 'C' Primary Control Circuit High",
	PDTC(0x2308), "Ign. Coil 'C' Secondary Control Circuit",
	PDTC(0x2309), "Ign. Coil 'D' Primary Control Circuit Low",
	PDTC(0x2310), "Ign. Coil 'D' Primary Control Circuit High",
	PDTC(0x2311), "Ign. Coil 'D' Secondary Control Circuit",
	PDTC(0x2312), "Ign. Coil 'E' Primary Control Circuit Low",
	PDTC(0x2313), "Ign. Coil 'E' Primary Control Circuit High",
	PDTC(0x2314), "Ign. Coil 'E' Secondary Control Circuit",
	PDTC(0x2315), "Ign. Coil 'F' Primary Control Circuit Low",
	PDTC(0x2316), "Ign. Coil 'F' Primary Control Circuit High",
	PDTC(0x2317), "Ign. Coil 'F' Secondary Control Circuit",
	PDTC(0x2318), "Ign. Coil 'G' Primary Control Circuit Low",
	PDTC(0x2319), "Ign. Coil 'G' Primary Control Circuit High",
	PDTC(0x2320), "Ign. Coil 'G' Secondary Control Circuit",
	PDTC(0x2321), "Ign. Coil 'H' Primary Control Circuit Low",
	PDTC(0x2322), "Ign. Coil 'H' Primary Control Circuit High",
	PDTC(0x2323), "Ign. Coil 'H' Secondary Control Circuit",
	PDTC(0x2324), "Ign. Coil 'I' Primary Control Circuit Low",
	PDTC(0x2325), "Ign. Coil 'I' Primary Control Circuit High",
	PDTC(0x2326), "Ign. Coil 'I' Secondary Control Circuit",
	PDTC(0x2327), "Ign. Coil 'J' Primary Control Circuit Low",
	PDTC(0x2328), "Ign. Coil 'J' Primary Control Circuit High",
	PDTC(0x2329), "Ign. Coil 'J' Secondary Control Circuit",
	PDTC(0x2330), "Ign. Coil 'K' Primary Control Circuit Low",
	PDTC(0x2331), "Ign. Coil 'K' Primary Control Circuit High",
	PDTC(0x2332), "Ign. Coil 'K' Secondary Control Circuit",
	PDTC(0x2333), "Ign. Coil 'L' Primary Control Circuit Low",
	PDTC(0x2334), "Ign. Coil 'L' Primary Control Circuit High",
	PDTC(0x2335), "Ign. Coil 'L' Secondary Control Circuit",
	PDTC(0x2336), "Cylinder #1 Above Knock Threshold",
	PDTC(0x2337), "Cylinder #2 Above Knock Threshold",
	PDTC(0x2338), "Cylinder #3 Above Knock Threshold",
	PDTC(0x2339), "Cylinder #4 Above Knock Threshold",
	PDTC(0x2340), "Cylinder #5 Above Knock Threshold",
	PDTC(0x2341), "Cylinder #6 Above Knock Threshold",
	PDTC(0x2342), "Cylinder #7 Above Knock Threshold",
	PDTC(0x2343), "Cylinder #8 Above Knock Threshold",
	PDTC(0x2344), "Cylinder #9 Above Knock Threshold",
	PDTC(0x2345), "Cylinder #10 Above Knock Threshold",
	PDTC(0x2346), "Cylinder #11 Above Knock Threshold",
	PDTC(0x2347), "Cylinder #12 Above Knock Threshold",
	PDTC(0x2400), "Evap. Emission System Leak Det. Pump Control Circuit",
	PDTC(0x2401), "Evap. Emission System Leak Det. Pump Control Circuit Low",
	PDTC(0x2402), "Evap. Emission System Leak Det. Pump Control Circuit High",
	PDTC(0x2403), "Evap. Emission System Leak Det. Pump Sense Circuit",
	PDTC(0x2404), "Evap. Emission System Leak Det. Pump Sense Circuit Range/Perf.",
	PDTC(0x2405), "Evap. Emission System Leak Det. Pump Sense Circuit Low",
	PDTC(0x2406), "Evap. Emission System Leak Det. Pump Sense Circuit High",
	PDTC(0x2407), "Evap. Emission System Leak Det. Pump Sense Intermit.",
	PDTC(0x2408), "Fuel Cap Sensor/Switch Circuit",
	PDTC(0x2409), "Fuel Cap Sensor/Switch Circuit Range/Perf.",
	PDTC(0x2410), "Fuel Cap Sensor/Switch Circuit Low",
	PDTC(0x2411), "Fuel Cap Sensor/Switch Circuit High",
	PDTC(0x2412), "Fuel Cap Sensor/Switch Circuit Intermit.",
	PDTC(0x2413), "Exhaust Gas Recirculation System Perf.",
	PDTC(0x2414), "O2 Sensor Exhaust Sample Error (B1-S1)",
	PDTC(0x2415), "O2 Sensor Exhaust Sample Error (B2-S1)",
	PDTC(0x2416), "O2 Sensor Signals Swapped B1-S2 / B1-S3",
	PDTC(0x2417), "O2 Sensor Signals Swapped B2-S2 / B2-S3",
	PDTC(0x2418), "Evap. Emission System Switching Valve Control Circuit",
	PDTC(0x2419), "Evap. Emission System Switching Valve Control Circuit Low",
	PDTC(0x2420), "Evap. Emission System Switching Valve Control Circuit High",
	PDTC(0x2421), "Evap. Emission System Vent Valve Stuck Open",
	PDTC(0x2422), "Evap. Emission System Vent Valve Stuck Closed",
	PDTC(0x2423), "HC Adsorption Catalyst Efficiency Below Threshold (B1)",
	PDTC(0x2424), "HC Adsorption Catalyst Efficiency Below Threshold (B2)",
	PDTC(0x2425), "Exhaust Gas Recirculation Cooloing Valve Control Circuit",
	PDTC(0x2426), "Exhaust Gas Recirculation Cooloing Valve Control Circuit Low",
	PDTC(0x2427), "Exhaust Gas Recirculation Cooloing Valve Control Circuit High",
	PDTC(0x2428), "Exhaust Gas Temp. Too High (B1)",
	PDTC(0x2429), "Exhaust Gas Temp. Too High (B2)",
	PDTC(0x2430), "Sec. Air Inj. Sys. Air Flow Sensor Circuit (B1)",
	PDTC(0x2431), "Sec. Air Inj. Sys. Air Flow Sensor Circuit Range/Perf. (B1)",
	PDTC(0x2432), "Sec. Air Inj. Sys. Air Flow Sensor Circuit Low (B1)",
	PDTC(0x2433), "Sec. Air Inj. Sys. Air Flow Sensor Circuit High (B1)",
	PDTC(0x2434), "Sec. Air Inj. Sys. Air Flow Sensor Circuit Intermit. (B1)",
	PDTC(0x2435), "Sec. Air Inj. Sys. Air Flow Sensor Circuit (B2)",
	PDTC(0x2436), "Sec. Air Inj. Sys. Air Flow Sensor Circuit Range/Perf. (B2)",
	PDTC(0x2437), "Sec. Air Inj. Sys. Air Flow Sensor Circuit Low (B2)",
	PDTC(0x2438), "Sec. Air Inj. Sys. Air Flow Sensor Circuit High (B2)",
	PDTC(0x2439), "Sec. Air Inj. Sys. Air Flow Sensor Circuit Intermit. (B2)",
	PDTC(0x2440), "Sec. Air Inj. Sys. Switching Valve Stuck Open (B1)",
	PDTC(0x2441), "Sec. Air Inj. Sys. Switching Valve Stuck Closed (B1)",
	PDTC(0x2442), "Sec. Air Inj. Sys. Switching Valve Stuck Open (B2)",
	PDTC(0x2443), "Sec. Air Inj. Sys. Switching Valve Stuck Closed (B2)",
	PDTC(0x2444), "Sec. Air Inj. Sys. Pump Stuck On (B1)",
	PDTC(0x2445), "Sec. Air Inj. Sys. Pump Stuck Off (B1)",
	PDTC(0x2446), "Sec. Air Inj. Sys. Pump Stuck On (B2)",
	PDTC(0x2447), "Sec. Air Inj. Sys. Pump Stuck Off (B2)",
	PDTC(0x2500), "Generator Lamp/L-Terminal Circuit Low",
	PDTC(0x2501), "Generator Lamp/L-Terminal Circuit High",
	PDTC(0x2502), "Charging System Voltage",
	PDTC(0x2503), "Charging System Voltage Low",
	PDTC(0x2504), "Charging System Voltage High",
	PDTC(0x2505), "ECM/PCM Power Input Signal",
	PDTC(0x2506), "ECM/PCM Power Input Signal Range",
	PDTC(0x2507), "ECM/PCM Power Input Signal Low",
	PDTC(0x2508), "ECM/PCM Power Input Signal High",
	PDTC(0x2509), "ECM/PCM Power Input Signal Intermit.",
	PDTC(0x2510), "ECM/PCM Power Relay Sense Circuit Range/Perf.",
	PDTC(0x2511), "ECM/PCM Power Relay Sense Circuit Intermit.",
	PDTC(0x2512), "Event Data Recorder Request Circuit",
	PDTC(0x2513), "Event Data Recorder Request Circuit Low",
	PDTC(0x2514), "Event Data Recorder Request Circuit High",
	PDTC(0x2515), "A/C Refrigerant Pres. Sensor 'B' Circuit",
	PDTC(0x2516), "A/C Refrigerant Pres. Sensor 'B' Circuit Range/Perf.",
	PDTC(0x2517), "A/C Refrigerant Pres. Sensor 'B' Circuit Low",
	PDTC(0x2518), "A/C Refrigerant Pres. Sensor 'B' Circuit High",
	PDTC(0x2519), "A/C Request 'A' Circuit",
	PDTC(0x2520), "A/C Request 'A' Circuit Low",
	PDTC(0x2521), "A/C Request 'A' Circuit High",
	PDTC(0x2522), "A/C Request 'B' Circuit",
	PDTC(0x2523), "A/C Request 'B' Circuit Low",
	PDTC(0x2524), "A/C Request 'B' Circuit High",
	PDTC(0x2525), "Vacuum Reservoir Pres. Sensor Circuit",
	PDTC(0x2526), "Vacuum Reservoir Pres. Sensor Circuit Range/Perf.",
	PDTC(0x2527), "Vacuum Reservoir Pres. Sensor Circuit Low",
	PDTC(0x2528), "Vacuum Reservoir Pres. Sensor Circuit High",
	PDTC(0x2529), "Vacuum Reservoir Pres. Sensor Circuit Intermit.",
	PDTC(0x2530), "Ign. Switch Run Position Circuit",
	PDTC(0x2531), "Ign. Switch Run Position Circuit Low",
	PDTC(0x2532), "Ign. Switch Run Position Circuit High",
	PDTC(0x2533), "Ign. Switch Run/Start Position Circuit",
	PDTC(0x2534), "Ign. Switch Run/Start Position Circuit Low",
	PDTC(0x2535), "Ign. Switch Run/Start Position Circuit High",
	PDTC(0x2536), "Ign. Switch Accessory Position Circuit",
	PDTC(0x2537), "Ign. Switch Accessory Position Circuit Low",
	PDTC(0x2538), "Ign. Switch Accessory Position Circuit High",
	PDTC(0x2539), "Low Pres. Fuel System Sensor Circuit",
	PDTC(0x2540), "Low Pres. Fuel System Sensor Circuit Range/Perf.",
	PDTC(0x2541), "Low Pres. Fuel System Sensor Circuit Low",
	PDTC(0x2542), "Low Pres. Fuel System Sensor Circuit High",
	PDTC(0x2543), "Low Pres. Fuel System Sensor Circuit Intermit.",
	PDTC(0x2544), "Torque Management Request Input Signal 'A'",
	PDTC(0x2545), "Torque Management Request Input Signal 'A' Range/Perf.",
	PDTC(0x2546), "Torque Management Request Input Signal 'A' Low",
	PDTC(0x2547), "Torque Management Request Input Signal 'A' High",
	PDTC(0x2548), "Torque Management Request Input Signal 'B' ",
	PDTC(0x2549), "Torque Management Request Input Signal 'B' Range/Perf.",
	PDTC(0x2550), "Torque Management Request Input Signal 'B' Low",
	PDTC(0x2551), "Torque Management Request Input Signal 'B' High",
	PDTC(0x2552), "Throttle/Fuel Inhibit Circuit",
	PDTC(0x2553), "Throttle/Fuel Inhibit Circuit Range/Perf.",
	PDTC(0x2554), "Throttle/Fuel Inhibit Circuit Low",
	PDTC(0x2555), "Throttle/Fuel Inhibit Circuit High",
	PDTC(0x2556), "Engine Coolant Level Sensor/Switch Circuit",
	PDTC(0x2557), "Engine Coolant Level Sensor/Switch Circuit Range/Perf.",
	PDTC(0x2558), "Engine Coolant Level Sensor/Switch Circuit Low",
	PDTC(0x2559), "Engine Coolant Level Sensor/Switch Circuit High",
	PDTC(0x2560), "Engine Coolant Level Low",
	PDTC(0x2561), "A/C Control Module Requested MIL Illumination",
	PDTC(0x2562), "Turbocharger Boost Control Pos. Sensor Circuit",
	PDTC(0x2563), "Turbocharger Boost Control Pos. Sensor Circuit Range/Perf.",
	PDTC(0x2564), "Turbocharger Boost Control Pos. Sensor Circuit Low",
	PDTC(0x2565), "Turbocharger Boost Control Pos. Sensor Circuit High",
	PDTC(0x2566), "Turbocharger Boost Control Pos. Sensor Circuit Intermit.",
	PDTC(0x2567), "Direct Ozone Red. Catalyst Temp. Sensor Circuit",
	PDTC(0x2568), "Direct Ozone Red. Catalyst Temp. Sensor Circuit Range/Perf.",
	PDTC(0x2569), "Direct Ozone Red. Catalyst Temp. Sensor Circuit Low",
	PDTC(0x2570), "Direct Ozone Red. Catalyst Temp. Sensor Circuit High",
	PDTC(0x2571), "Direct Ozone Red. Catalyst Temp. Sensor Circuit Intermit.",
	PDTC(0x2572), "Direct Ozone Red. Catalyst Det. Sensor Circuit",
	PDTC(0x2573), "Direct Ozone Red. Catalyst Det. Sensor Circuit Range/Perf.",
	PDTC(0x2574), "Direct Ozone Red. Catalyst Det. Sensor Circuit Low",
	PDTC(0x2575), "Direct Ozone Red. Catalyst Det. Sensor Circuit High",
	PDTC(0x2576), "Direct Ozone Red. Catalyst Det. Sensor Circuit Intermit.",
	PDTC(0x2577), "Direct Ozone Red. Catalyst Efficiency Below Threshhold",
	PDTC(0x2600), "Coolant Pump Control Circuit",
	PDTC(0x2601), "Coolant Pump Control Circuit Range/Perf.",
	PDTC(0x2602), "Coolant Pump Control Circuit Low",
	PDTC(0x2603), "Coolant Pump Control Circuit High",
	PDTC(0x2604), "Intake Air Heater 'A' Circuit Range/Perf.",
	PDTC(0x2605), "Intake Air Heater 'A' Circuit",
	PDTC(0x2606), "Intake Air Heater 'B' Circuit Range/Perf.",
	PDTC(0x2607), "Intake Air Heater 'B' Circuit Low",
	PDTC(0x2608), "Intake Air Heater 'B' Circuit High",
	PDTC(0x2609), "Intake Air Heater System Perf.",
	PDTC(0x2610), "ECM/PCM Internal Engine Off Timer Perf.",
	PDTC(0x2611), "A/C Refrigerant Distribution Valve Control Circuit",
	PDTC(0x2612), "A/C Refrigerant Distribution Valve Control Circuit Low",
	PDTC(0x2613), "A/C Refrigerant Distribution Valve Control Circuit High",
	PDTC(0x2614), "Camshaft Position Siganl Output Circuit",
	PDTC(0x2615), "Camshaft Position Siganl Output Circuit Low",
	PDTC(0x2616), "Camshaft Position Siganl Output Circuit High",
	PDTC(0x2617), "Crankshaft Position Signle Output Circuit",
	PDTC(0x2618), "Crankshaft Position Signle Output Circuit Low",
	PDTC(0x2619), "Crankshaft Position Signle Output Circuit High",
	PDTC(0x2620), "Throttle Position Ouput Circuit",
	PDTC(0x2621), "Throttle Position Ouput Circuit Low",
	PDTC(0x2622), "Throttle Position Ouput Circuit High",
	PDTC(0x2623), "Injector Control Pres. Regulator Circuit",
	PDTC(0x2624), "Injector Control Pres. Regulator Circuit Low",
	PDTC(0x2625), "Injector Control Pres. Regulator Circuit High",
	PDTC(0x2626), "O2 Sensor Pumping Current Trim Circuit (B1-S1)",
	PDTC(0x2627), "O2 Sensor Pumping Current Trim Circuit Low (B1-S1)",
	PDTC(0x2628), "O2 Sensor Pumping Current Trim Circuit High (B1-S1)",
	PDTC(0x2629), "O2 Sensor Pumping Current Trim Circuit (B2-S1)",
	PDTC(0x2630), "O2 Sensor Pumping Current Trim Circuit Low (B2-S1)",
	PDTC(0x2631), "O2 Sensor Pumping Current Trim Circuit High (B2-S1)",
	PDTC(0x2632), "Fuel Pump 'B' Control Circuit",
	PDTC(0x2633), "Fuel Pump 'B' Control Circuit Low",
	PDTC(0x2634), "Fuel Pump 'B' Control Circuit High",
	PDTC(0x2635), "Fuel Pump 'A' Low Flow/Perf.",
	PDTC(0x2636), "Fuel Pump 'B' Low Flow/Perf.",
	PDTC(0x2637), "Torque Management Feedback Signal 'A'",
	PDTC(0x2638), "Torque Management Feedback Signal 'A' Range/Perf.",
	PDTC(0x2639), "Torque Management Feedback Signal 'A' Low",
	PDTC(0x2640), "Torque Management Feedback Signal 'A' High",
	PDTC(0x2641), "Torque Management Feedback Signal 'B'",
	PDTC(0x2642), "Torque Management Feedback Signal 'B' Range/Perf.",
	PDTC(0x2643), "Torque Management Feedback Signal 'B' Low",
	PDTC(0x2644), "Torque Management Feedback Signal 'B' High",
	PDTC(0x2645), "'A' Rocker Arm Actuator Control Circuit (B1)",
	PDTC(0x2646), "'A' Rocker Arm Actuator Control Perf. or Stuck Off (B1)",
	PDTC(0x2647), "'A' Rocker Arm Actuator Control Stuck On (B1)",
	PDTC(0x2648), "'A' Rocker Arm Actuator Control Circuit Low (B1)",
	PDTC(0x2649), "'A' Rocker Arm Actuator Control Circuit High (B1)",
	PDTC(0x2650), "'B' Rocker Arm Actuator Control Circuit (B1)",
	PDTC(0x2651), "'B' Rocker Arm Actuator Control Perf. or Stuck Off (B1)",
	PDTC(0x2652), "'B' Rocker Arm Actuator Control Stuck On (B1)",
	PDTC(0x2653), "'B' Rocker Arm Actuator Control Circuit Low (B1)",
	PDTC(0x2654), "'B' Rocker Arm Actuator Control Circuit High (B1)",
	PDTC(0x2655), "'A' Rocker Arm Actuator Control Circuit (B2)",
	PDTC(0x2656), "'A' Rocker Arm Actuator Control Perf. or Stuck Off (B2)",
	PDTC(0x2657), "'A' Rocker Arm Actuator Control Stuck On (B2)",
	PDTC(0x2658), "'A' Rocker Arm Actuator Control Circuit Low (B2)",
	PDTC(0x2659), "'A' Rocker Arm Actuator Control Circuit High (B2)",
	PDTC(0x2660), "'B' Rocker Arm Actuator Control Circuit (B2)",
	PDTC(0x2661), "'B' Rocker Arm Actuator Control Perf. or Stuck Off (B2)",
	PDTC(0x2662), "'B' Rocker Arm Actuator Control Stuck On (B2)",
	PDTC(0x2663), "'B' Rocker Arm Actuator Control Circuit Low (B2)",
	PDTC(0x2664), "'B' Rocker Arm Actuator Control Circuit High (B2)",
	PDTC(0x2665), "Fuel Shutoff Valve 'B' Control Circuit",
	PDTC(0x2666), "Fuel Shutoff Valve 'B' Control Circuit Low",
	PDTC(0x2667), "Fuel Shutoff Valve 'B' Control Circuit High",
	PDTC(0x2668), "Fuel Mode Indicator Lamp Control Circuit",
	PDTC(0x2669), "Actuator Supply Voltage 'B' Circuit",
	PDTC(0x2670), "Actuator Supply Voltage 'B' Circuit Low",
	PDTC(0x2671), "Actuator Supply Voltage 'B' Circuit High",
	PDTC(0x2700), "Trans. Friction Element 'A' Apply Time Range/Perf.",
	PDTC(0x2701), "Trans. Friction Element 'B' Apply Time Range/Perf.",
	PDTC(0x2702), "Trans. Friction Element 'C' Apply Time Range/Perf.",
	PDTC(0x2703), "Trans. Friction Element 'D' Apply Time Range/Perf.",
	PDTC(0x2704), "Trans. Friction Element 'E' Apply Time Range/Perf.",
	PDTC(0x2705), "Trans. Friction Element 'F' Apply Time Range/Perf.",
	PDTC(0x2706), "Shift Sol. 'F'",
	PDTC(0x2707), "Shift Sol. 'F' Perf. or Stuck Off",
	PDTC(0x2708), "Shift Sol. 'F' Stuck On",
	PDTC(0x2709), "Shift Sol. 'F' Electrical",
	PDTC(0x2710), "Shift Sol. 'F' Intermit.",
	PDTC(0x2711), "Unexpected Mechanical Gear Disengagement",
	PDTC(0x2712), "Hydraulic Power Unit Leakage",
	PDTC(0x2713), "Pres. Control Sol. 'D'",
	PDTC(0x2714), "Pres. Control Sol. 'D' Perf. or Stuck Off",
	PDTC(0x2715), "Pres. Control Sol. 'D' Stuck On",
	PDTC(0x2716), "Pres. Control Sol. 'D' Electrical",
	PDTC(0x2717), "Pres. Control Sol. 'D' Intermit.",
	PDTC(0x2718), "Pres. Control Sol. 'D' Control Circuit",
	PDTC(0x2719), "Pres. Control Sol. 'D' Control Circuit Range/Perf.",
	PDTC(0x2720), "Pres. Control Sol. 'D' Control Circuit Low",
	PDTC(0x2721), "Pres. Control Sol. 'D' Control Circuit High",
	PDTC(0x2722), "Pres. Control Sol. 'E'",
	PDTC(0x2723), "Pres. Control Sol. 'E' Perf. or Stuck Off",
	PDTC(0x2724), "Pres. Control Sol. 'E' Stuck On",
	PDTC(0x2725), "Pres. Control Sol. 'E' Electrical",
	PDTC(0x2726), "Pres. Control Sol. 'E' Intermit.",
	PDTC(0x2727), "Pres. Control Sol. 'E' Control Circuit",
	PDTC(0x2728), "Pres. Control Sol. 'E' Control Circuit Range/Perf.",
	PDTC(0x2729), "Pres. Control Sol. 'E' Control Circuit Low",
	PDTC(0x2730), "Pres. Control Sol. 'E' Control Circuit High",
	PDTC(0x2731), "Pres. Control Sol. 'F'",
	PDTC(0x2732), "Pres. Control Sol. 'F' Perf. or Stuck Off",
	PDTC(0x2733), "Pres. Control Sol. 'F' Stuck On",
	PDTC(0x2734), "Pres. Control Sol. 'F' Electrical",
	PDTC(0x2735), "Pres. Control Sol. 'F' Intermit.",
	PDTC(0x2736), "Pres. Control Sol. 'F' Control Circuit",
	PDTC(0x2737), "Pres. Control Sol. 'F' Control Circuit Range/Perf.",
	PDTC(0x2738), "Pres. Control Sol. 'F' Control Circuit Low",
	PDTC(0x2739), "Pres. Control Sol. 'F' Control Circuit High",
	PDTC(0x2740), "Trans. Fluid Temp. Sensor 'B' Circuit",
	PDTC(0x2741), "Trans. Fluid Temp. Sensor 'B' Circuit Range/Perf.",
	PDTC(0x2742), "Trans. Fluid Temp. Sensor 'B' Circuit Low",
	PDTC(0x2743), "Trans. Fluid Temp. Sensor 'B' Circuit High",
	PDTC(0x2744), "Trans. Fluid Temp. Sensor 'B' Circuit Intermit.",
	PDTC(0x2745), "Interm. Shaft Speed Sensor 'B' Circuit",
	PDTC(0x2746), "Interm. Shaft Speed Sensor 'B' Circuit Range/Perf.",
	PDTC(0x2747), "Interm. Shaft Speed Sensor 'B' Circuit No Signal",
	PDTC(0x2748), "Interm. Shaft Speed Sensor 'B' Circuit Intermit.",
	PDTC(0x2749), "Interm. Shaft Speed Sensor 'C' Circuit",
	PDTC(0x2750), "Interm. Shaft Speed Sensor 'C' Circuit Range/Perf.",
	PDTC(0x2751), "Interm. Shaft Speed Sensor 'C' Circuit No Signal",
	PDTC(0x2752), "Interm. Shaft Speed Sensor 'C' Circuit Intermit.",
	PDTC(0x2753), "Trans. Fluid Cooler Control Circuit",
	PDTC(0x2754), "Trans. Fluid Cooler Control Circuit Low",
	PDTC(0x2755), "Trans. Fluid Cooler Control Circuit High",
	PDTC(0x2756), "Torque Conv. Clutch Pres. Control Sol.",
	PDTC(0x2757), "Torque Conv. Clutch Pres. Control Sol. Stuck Off",
	PDTC(0x2758), "Torque Conv. Clutch Pres. Control Sol. Stuck On",
	PDTC(0x2759), "Torque Conv. Clutch Pres. Control Sol. Elec.",
	PDTC(0x2760), "Torque Conv. Clutch Pres. Control Sol. Intermit.",
	PDTC(0x2761), "Torque Conv. Clutch Pres. Control Sol. Open",
	PDTC(0x2762), "Torque Conv. Clutch Pres. Control Sol. Range",
	PDTC(0x2763), "Torque Conv. Clutch Pres. Control Sol. High",
	PDTC(0x2764), "Torque Conv. Clutch Pres. Control Sol. Low",
	PDTC(0x2765), "Input/Turbine Speed Sensor 'B' Circuit",
	PDTC(0x2766), "Input/Turbine Speed Sensor 'B' Circuit Range/Perf.",
	PDTC(0x2767), "Input/Turbine Speed Sensor 'B' Circuit No Signal",
	PDTC(0x2768), "Input/Turbine Speed Sensor 'B' Circuit Intermit.",
	PDTC(0x2769), "Torque Converter Clutch Circuit Low",
	PDTC(0x2770), "Torque Converter Clutch Circuit High",
	PDTC(0x2771), "4WD Low Switch Circuit",
	PDTC(0x2772), "4WD Low Switch Circuit Range/Perf.",
	PDTC(0x2773), "4WD Low Switch Circuit Low",
	PDTC(0x2774), "4WD Low Switch Circuit High",
	PDTC(0x2775), "Upshift Switch Circuit Range/Perf.",
	PDTC(0x2776), "Upshift Switch Circuit Low",
	PDTC(0x2777), "Upshift Switch Circuit High",
	PDTC(0x2778), "Upshift Switch Circuit Intermit.",
	PDTC(0x2779), "Downshift Switch Circuit Range/Perf.",
	PDTC(0x2780), "Downshift Switch Circuit Low",
	PDTC(0x2781), "Downshift Switch Circuit High",
	PDTC(0x2782), "Downshift Switch Circuit Intermit.",
	PDTC(0x2783), "Torque Conv. Temp. Too High",
	PDTC(0x2784), "Input/Turbine Speed Sensor A/B Correlation",
	PDTC(0x2785), "Clutch Actuator Temp. Too High",
	PDTC(0x2786), "Gear Shift Actuator Temp. Too High",
	PDTC(0x2787), "Clutch Temp. Too High",
	PDTC(0x2788), "Auto Shift Manual Adaptive Learning at Limit",
	PDTC(0x2789), "Clutch Adaptive Learning at Limit",
	PDTC(0x2790), "Gate Select Direction Circuit",
	PDTC(0x2791), "Gate Select Direction Circuit Low",
	PDTC(0x2792), "Gate Select Direction Circuit High",
	PDTC(0x2793), "Gear Shift Direction Circuit",
	PDTC(0x2794), "Gear Shift Direction Circuit Low",
	PDTC(0x2795), "Gear Shift Direction Circuit High",
	PDTC(0x2A00), "O2 Sensor Circuit Range/Perf. (B1-S1)",
	PDTC(0x2A01), "O2 Sensor Circuit Range/Perf. (B1-S2)",
	PDTC(0x2A02), "O2 Sensor Circuit Range/Perf. (B1-S3)",
	PDTC(0x2A03), "O2 Sensor Circuit Range/Perf. (B2-S1)",
	PDTC(0x2A04), "O2 Sensor Circuit Range/Perf. (B2-S2)",
	PDTC(0x2A05), "O2 Sensor Circuit Range/Perf. (B2-S3)",
	PDTC(0x3400), "Cyl. Deact. System (B1)",
	PDTC(0x3401), "Cyl. 1 Deact./Intake Valve Control Circuit",
	PDTC(0x3402), "Cyl. 1 Deact./Intake Valve Control Perf.",
	PDTC(0x3403), "Cyl. 1 Deact./Intake Valve Control Circuit Low",
	PDTC(0x3404), "Cyl. 1 Deact./Intake Valve Control Circuit High",
	PDTC(0x3405), "Cyl. 1 Exhaust Valve Control Circuit",
	PDTC(0x3406), "Cyl. 1 Exhaust Valve Control Perf.",
	PDTC(0x3407), "Cyl. 1 Exhaust Valve Control Circuit Low",
	PDTC(0x3408), "Cyl. 1 Exhaust Valve Control Circuit High",
	PDTC(0x3409), "Cyl. 2 Deact./Intake Valve Control Circuit",
	PDTC(0x3410), "Cyl. 2 Deact./Intake Valve Control Perf.",
	PDTC(0x3411), "Cyl. 2 Deact./Intake Valve Control Circuit Low",
	PDTC(0x3412), "Cyl. 2 Deact./Intake Valve Control Circuit High",
	PDTC(0x3413), "Cyl. 2 Exhaust Valve Control Circuit",
	PDTC(0x3414), "Cyl. 2 Exhaust Valve Control Perf.",
	PDTC(0x3415), "Cyl. 2 Exhaust Valve Control Circuit Low",
	PDTC(0x3416), "Cyl. 2 Exhaust Valve Control Circuit High",
	PDTC(0x3417), "Cyl. 3 Deact./Intake Valve Control Circuit",
	PDTC(0x3418), "Cyl. 3 Deact./Intake Valve Control Perf.",
	PDTC(0x3419), "Cyl. 3 Deact./Intake Valve Control Circuit Low",
	PDTC(0x3420), "Cyl. 3 Deact./Intake Valve Control Circuit High",
	PDTC(0x3421), "Cyl. 3 Exhaust Valve Control Circuit",
	PDTC(0x3422), "Cyl. 3 Exhaust Valve Control Perf.",
	PDTC(0x3423), "Cyl. 3 Exhaust Valve Control Circuit Low",
	PDTC(0x3424), "Cyl. 3 Exhaust Valve Control Circuit High",
	PDTC(0x3425), "Cyl. 4 Deact./Intake Valve Control Circuit",
	PDTC(0x3426), "Cyl. 4 Deact./Intake Valve Control Perf.",
	PDTC(0x3427), "Cyl. 4 Deact./Intake Valve Control Circuit Low",
	PDTC(0x3428), "Cyl. 4 Deact./Intake Valve Control Circuit High",
	PDTC(0x3429), "Cyl. 4 Exhaust Valve Control Circuit",
	PDTC(0x3430), "Cyl. 4 Exhaust Valve Control Perf.",
	PDTC(0x3431), "Cyl. 4 Exhaust Valve Control Circuit Low",
	PDTC(0x3432), "Cyl. 4 Exhaust Valve Control Circuit High",
	PDTC(0x3433), "Cyl. 5 Deact./Intake Valve Control Circuit",
	PDTC(0x3434), "Cyl. 5 Deact./Intake Valve Control Perf.",
	PDTC(0x3435), "Cyl. 5 Deact./Intake Valve Control Circuit Low",
	PDTC(0x3436), "Cyl. 5 Deact./Intake Valve Control Circuit High",
	PDTC(0x3437), "Cyl. 5 Exhaust Valve Control Circuit",
	PDTC(0x3438), "Cyl. 5 Exhaust Valve Control Perf.",
	PDTC(0x3439), "Cyl. 5 Exhaust Valve Control Circuit Low",
	PDTC(0x3440), "Cyl. 5 Exhaust Valve Control Circuit High",
	PDTC(0x3441), "Cyl. 6 Deact./Intake Valve Control Circuit",
	PDTC(0x3442), "Cyl. 6 Deact./Intake Valve Control Perf.",
	PDTC(0x3443), "Cyl. 6 Deact./Intake Valve Control Circuit Low",
	PDTC(0x3444), "Cyl. 6 Deact./Intake Valve Control Circuit High",
	PDTC(0x3445), "Cyl. 6 Exhaust Valve Control Circuit",
	PDTC(0x3446), "Cyl. 6 Exhaust Valve Control Perf.",
	PDTC(0x3447), "Cyl. 6 Exhaust Valve Control Circuit Low",
	PDTC(0x3448), "Cyl. 6 Exhaust Valve Control Circuit High",
	PDTC(0x3449), "Cyl. 7 Deact./Intake Valve Control Circuit",
	PDTC(0x3450), "Cyl. 7 Deact./Intake Valve Control Perf.",
	PDTC(0x3451), "Cyl. 7 Deact./Intake Valve Control Circuit Low",
	PDTC(0x3452), "Cyl. 7 Deact./Intake Valve Control Circuit High",
	PDTC(0x3453), "Cyl. 7 Exhaust Valve Control Circuit",
	PDTC(0x3454), "Cyl. 7 Exhaust Valve Control Perf.",
	PDTC(0x3455), "Cyl. 7 Exhaust Valve Control Circuit Low",
	PDTC(0x3456), "Cyl. 7 Exhaust Valve Control Circuit High",
	PDTC(0x3457), "Cyl. 8 Deact./Intake Valve Control Circuit",
	PDTC(0x3458), "Cyl. 8 Deact./Intake Valve Control Perf.",
	PDTC(0x3459), "Cyl. 8 Deact./Intake Valve Control Circuit Low",
	PDTC(0x3460), "Cyl. 8 Deact./Intake Valve Control Circuit High",
	PDTC(0x3461), "Cyl. 8 Exhaust Valve Control Circuit",
	PDTC(0x3462), "Cyl. 8 Exhaust Valve Control Perf.",
	PDTC(0x3463), "Cyl. 8 Exhaust Valve Control Circuit Low",
	PDTC(0x3464), "Cyl. 8 Exhaust Valve Control Circuit High",
	PDTC(0x3465), "Cyl. 9 Deact./Intake Valve Control Circuit",
	PDTC(0x3466), "Cyl. 9 Deact./Intake Valve Control Perf.",
	PDTC(0x3467), "Cyl. 9 Deact./Intake Valve Control Circuit Low",
	PDTC(0x3468), "Cyl. 9 Deact./Intake Valve Control Circuit High",
	PDTC(0x3469), "Cyl. 9 Exhaust Valve Control Circuit",
	PDTC(0x3470), "Cyl. 9 Exhaust Valve Control Perf.",
	PDTC(0x3471), "Cyl. 9 Exhaust Valve Control Circuit Low",
	PDTC(0x3472), "Cyl. 9 Exhaust Valve Control Circuit High",
	PDTC(0x3473), "Cyl. 10 Deact./Intake Valve Control Circuit",
	PDTC(0x3474), "Cyl. 10 Deact./Intake Valve Control Perf.",
	PDTC(0x3475), "Cyl. 10 Deact./Intake Valve Control Circuit Low",
	PDTC(0x3476), "Cyl. 10 Deact./Intake Valve Control Circuit High",
	PDTC(0x3477), "Cyl. 10 Exhaust Valve Control Circuit",
	PDTC(0x3478), "Cyl. 10 Exhaust Valve Control Perf.",
	PDTC(0x3479), "Cyl. 10 Exhaust Valve Control Circuit Low",
	PDTC(0x3481), "Cyl. 10 Exhaust Valve Control Circuit High",
	PDTC(0x3481), "Cyl. 11 Deact./Intake Valve Control Circuit",
	PDTC(0x3482), "Cyl. 11 Deact./Intake Valve Control Perf.",
	PDTC(0x3483), "Cyl. 11 Deact./Intake Valve Control Circuit Low",
	PDTC(0x3484), "Cyl. 11 Deact./Intake Valve Control Circuit High",
	PDTC(0x3485), "Cyl. 11 Exhaust Valve Control Circuit",
	PDTC(0x3486), "Cyl. 11 Exhaust Valve Control Perf.",
	PDTC(0x3487), "Cyl. 11 Exhaust Valve Control Circuit Low",
	PDTC(0x3488), "Cyl. 11 Exhaust Valve Control Circuit High",
	PDTC(0x3489), "Cyl. 12 Deact./Intake Valve Control Circuit",
	PDTC(0x3490), "Cyl. 12 Deact./Intake Valve Control Perf.",
	PDTC(0x3491), "Cyl. 12 Deact./Intake Valve Control Circuit Low",
	PDTC(0x3492), "Cyl. 12 Deact./Intake Valve Control Circuit High",
	PDTC(0x3493), "Cyl. 12 Exhaust Valve Control Circuit",
	PDTC(0x3494), "Cyl. 12 Exhaust Valve Control Perf.",
	PDTC(0x3495), "Cyl. 12 Exhaust Valve Control Circuit Low",
	PDTC(0x3496), "Cyl. 12 Exhaust Valve Control Circuit High",
	PDTC(0x3497), "Cyl. Deact. System (B2)",
	UDTC(0x0001), "High Speed CAN Comm. Bus",
	UDTC(0x0002), "High Speed CAN Comm. Bus Perf.",
	UDTC(0x0003), "High Speed CAN Comm. Bus (+) Open",
	UDTC(0x0004), "High Speed CAN Comm. Bus (+) Low",
	UDTC(0x0005), "High Speed CAN Comm. Bus (+) High",
	UDTC(0x0006), "High Speed CAN Comm. Bus (-) Open",
	UDTC(0x0007), "High Speed CAN Comm. Bus (-) Low",
	UDTC(0x0008), "High Speed CAN Comm. Bus (-) High",
	UDTC(0x0009), "High Speed CAN Comm. Bus (-) shorted to Bus (+)",
	UDTC(0x0010), "Medium Speed CAN Comm. Bus",
	UDTC(0x0011), "Medium Speed CAN Comm. Bus Perf.",
	UDTC(0x0012), "Medium Speed CAN Comm. Bus (+) Open",
	UDTC(0x0013), "Medium Speed CAN Comm. Bus (+) Low",
	UDTC(0x0014), "Medium Speed CAN Comm. Bus (+) High",
	UDTC(0x0015), "Medium Speed CAN Comm. Bus (-) Open",
	UDTC(0x0016), "Medium Speed CAN Comm. Bus (-) Low",
	UDTC(0x0017), "Medium Speed CAN Comm. Bus (-) High",
	UDTC(0x0018), "Medium Speed CAN Comm. Bus (-) shorted to Bus (+)",
	UDTC(0x0019), "Low Speed CAN Comm. Bus",
	UDTC(0x0020), "Low Speed CAN Comm. Bus Perf.",
	UDTC(0x0021), "Low Speed CAN Comm. Bus (+) Open",
	UDTC(0x0022), "Low Speed CAN Comm. Bus (+) Low",
	UDTC(0x0023), "Low Speed CAN Comm. Bus (+) High",
	UDTC(0x0024), "Low Speed CAN Comm. Bus (-) Open",
	UDTC(0x0025), "Low Speed CAN Comm. Bus (-) Low",
	UDTC(0x0026), "Low Speed CAN Comm. Bus (-) High",
	UDTC(0x0027), "Low Speed CAN Comm. Bus (-) shorted to Bus (+)",
	UDTC(0x0028), "Vehicle Comm. Bus A",
	UDTC(0x0029), "Vehicle Comm. Bus A Perf.",
	UDTC(0x0030), "Vehicle Comm. Bus A (+) Open",
	UDTC(0x0031), "Vehicle Comm. Bus A (+) Low",
	UDTC(0x0032), "Vehicle Comm. Bus A (+) High",
	UDTC(0x0033), "Vehicle Comm. Bus A (-) Open",
	UDTC(0x0034), "Vehicle Comm. Bus A (-) Low",
	UDTC(0x0035), "Vehicle Comm. Bus A (-) High",
	UDTC(0x0036), "Vehicle Comm. Bus A (-) shorted to Bus A (+)",
	UDTC(0x0037), "Vehicle Comm. Bus B",
	UDTC(0x0038), "Vehicle Comm. Bus B Perf.",
	UDTC(0x0039), "Vehicle Comm. Bus B (+) Open",
	UDTC(0x0040), "Vehicle Comm. Bus B (+) Low",
	UDTC(0x0041), "Vehicle Comm. Bus B (+) High",
	UDTC(0x0042), "Vehicle Comm. Bus B (-) Open",
	UDTC(0x0043), "Vehicle Comm. Bus B (-) Low",
	UDTC(0x0044), "Vehicle Comm. Bus B (-) High",
	UDTC(0x0045), "Vehicle Comm. Bus B (-) shorted to Bus B (+)",
	UDTC(0x0046), "Vehicle Comm. Bus C",
	UDTC(0x0047), "Vehicle Comm. Bus C Perf.",
	UDTC(0x0048), "Vehicle Comm. Bus C (+) Open",
	UDTC(0x0049), "Vehicle Comm. Bus C (+) Low",
	UDTC(0x0050), "Vehicle Comm. Bus C (+) High",
	UDTC(0x0051), "Vehicle Comm. Bus C (-) Open",
	UDTC(0x0052), "Vehicle Comm. Bus C (-) Low",
	UDTC(0x0053), "Vehicle Comm. Bus C (-) High",
	UDTC(0x0054), "Vehicle Comm. Bus C (-) shorted to Bus C (+)",
	UDTC(0x0055), "Vehicle Comm. Bus D",
	UDTC(0x0056), "Vehicle Comm. Bus D Perf.",
	UDTC(0x0057), "Vehicle Comm. Bus D (+) Open",
	UDTC(0x0058), "Vehicle Comm. Bus D (+) Low",
	UDTC(0x0059), "Vehicle Comm. Bus D (+) High",
	UDTC(0x0060), "Vehicle Comm. Bus D (-) Open",
	UDTC(0x0061), "Vehicle Comm. Bus D (-) Low",
	UDTC(0x0062), "Vehicle Comm. Bus D (-) High",
	UDTC(0x0063), "Vehicle Comm. Bus D (-) shorted to Bus D (+)",
	UDTC(0x0064), "Vehicle Comm. Bus E",
	UDTC(0x0065), "Vehicle Comm. Bus E Perf.",
	UDTC(0x0066), "Vehicle Comm. Bus E (+) Open",
	UDTC(0x0067), "Vehicle Comm. Bus E (+) Low",
	UDTC(0x0068), "Vehicle Comm. Bus E (+) High",
	UDTC(0x0069), "Vehicle Comm. Bus E (-) Open",
	UDTC(0x0070), "Vehicle Comm. Bus E (-) Low",
	UDTC(0x0071), "Vehicle Comm. Bus E (-) High",
	UDTC(0x0072), "Vehicle Comm. Bus E (-) shorted to Bus E (+)",
	UDTC(0x0073), "Control Module Comm. Bus Off",
	UDTC(0x0074), "Reserved!?",
	UDTC(0x0075), "Reserved!?",
	UDTC(0x0076), "Reserved!?",
	UDTC(0x0077), "Reserved!?",
	UDTC(0x0078), "Reserved!?",
	UDTC(0x0079), "Reserved!?",
	UDTC(0x0080), "Reserved!?",
	UDTC(0x0081), "Reserved!?",
	UDTC(0x0082), "Reserved!?",
	UDTC(0x0083), "Reserved!?",
	UDTC(0x0084), "Reserved!?",
	UDTC(0x0085), "Reserved!?",
	UDTC(0x0086), "Reserved!?",
	UDTC(0x0087), "Reserved!?",
	UDTC(0x0088), "Reserved!?",
	UDTC(0x0089), "Reserved!?",
	UDTC(0x0090), "Reserved!?",
	UDTC(0x0091), "Reserved!?",
	UDTC(0x0092), "Reserved!?",
	UDTC(0x0093), "Reserved!?",
	UDTC(0x0094), "Reserved!?",
	UDTC(0x0095), "Reserved!?",
	UDTC(0x0096), "Reserved!?",
	UDTC(0x0097), "Reserved!?",
	UDTC(0x0098), "Reserved!?",
	UDTC(0x0099), "Reserved!?",
	UDTC(0x0100), "Lost Comm. ECM/PCM 'A'",
	UDTC(0x0101), "Lost Comm. TCM",
	UDTC(0x0102), "Lost Comm. Transfer Case Control Module",
	UDTC(0x0103), "Lost Comm. Gear Shift Module",
	UDTC(0x0104), "Lost Comm. Cruise Control Module",
	UDTC(0x0105), "Lost Comm. Fuel Injector Module",
	UDTC(0x0106), "Lost Comm. Glow Plug Control Module",
	UDTC(0x0107), "Lost Comm. Throttle Actuator Control Module",
	UDTC(0x0108), "Lost Comm. Alternative Fuel Control Module",
	UDTC(0x0109), "Lost Comm. Fuel Pump Control Module",
	UDTC(0x0110), "Lost Comm. Drive Motor Control Module",
	UDTC(0x0111), "Lost Comm. Battery Energy Control Module 'A'",
	UDTC(0x0112), "Lost Comm. Battery Energy Control Module 'B'",
	UDTC(0x0113), "Lost Comm. Emmissions Critical Control Information",
	UDTC(0x0114), "Lost Comm. Four-Wheel Drive Clutch Control Module",
	UDTC(0x0115), "Lost Comm. ECM/PCM 'B'",
	UDTC(0x0116), "Reserved!?",
	UDTC(0x0117), "Reserved!?",
	UDTC(0x0118), "Reserved!?",
	UDTC(0x0119), "Reserved!?",
	UDTC(0x0120), "Reserved!?",
	UDTC(0x0121), "Lost Comm. ABS Control Module",
	UDTC(0x0122), "Lost Comm. Vehicle Dynamics Control Module",
	UDTC(0x0123), "Lost Comm. Yaw Rate Sensor Module",
	UDTC(0x0124), "Lost Comm. Lateral Acceleration Sensor Module",
	UDTC(0x0125), "Lost Comm. Multi-Axis Acceleration Sensor Module",
	UDTC(0x0126), "Lost Comm. Steering Angle Sensor Module",
	UDTC(0x0127), "Lost Comm. Tire Pres. Monitor Module",
	UDTC(0x0128), "Lost Comm. Park Brake Control Module",
	UDTC(0x0129), "Lost Comm. Brake System Control Module",
	UDTC(0x0130), "Lost Comm. Steering Effort Control Module",
	UDTC(0x0131), "Lost Comm. Power Steering Control Module",
	UDTC(0x0132), "Lost Comm. Ride Level Control Module",
	UDTC(0x0133), "Reserved!?",
	UDTC(0x0134), "Reserved!?",
	UDTC(0x0135), "Reserved!?",
	UDTC(0x0136), "Reserved!?",
	UDTC(0x0137), "Reserved!?",
	UDTC(0x0138), "Reserved!?",
	UDTC(0x0139), "Reserved!?",
	UDTC(0x0140), "Lost Comm. Body Control Module",
	UDTC(0x0141), "Lost Comm. Body Control Module 'A'",
	UDTC(0x0142), "Lost Comm. Body Control Module 'B'",
	UDTC(0x0143), "Lost Comm. Body Control Module 'C'",
	UDTC(0x0144), "Lost Comm. Body Control Module 'D'",
	UDTC(0x0145), "Lost Comm. Body Control Module 'E'",
	UDTC(0x0146), "Lost Comm. Gateway 'A'",
	UDTC(0x0147), "Lost Comm. Gateway 'B'",
	UDTC(0x0148), "Lost Comm. Gateway 'C'",
	UDTC(0x0149), "Lost Comm. Gateway 'D'",
	UDTC(0x0150), "Lost Comm. Gateway 'E'",
	UDTC(0x0151), "Lost Comm. Restraints Control Module",
	UDTC(0x0152), "Lost Comm. Side Restraints Control Module (L)",
	UDTC(0x0153), "Lost Comm. Side Restraints Control Module (R)",
	UDTC(0x0154), "Lost Comm. Restraints Occupant Sensing Control Module",
	UDTC(0x0155), "Lost Comm. Instrument Panel Cluster Control Module",
	UDTC(0x0156), "Lost Comm. Information Center 'A'",
	UDTC(0x0157), "Lost Comm. Information Center 'B'",
	UDTC(0x0158), "Lost Comm. Head Up Display",
	UDTC(0x0159), "Lost Comm. Parking Assist Control Module",
	UDTC(0x0160), "Lost Comm. Audible Alert Control Module",
	UDTC(0x0161), "Lost Comm. Compass Module",
	UDTC(0x0162), "Lost Comm. Navigation Display Module",
	UDTC(0x0163), "Lost Comm. Navigation Control Module",
	UDTC(0x0164), "Lost Comm. HVAC Control Module",
	UDTC(0x0165), "Lost Comm. Rear HVAC Control Module",
	UDTC(0x0166), "Lost Comm. Aux. Heater Control Module",
	UDTC(0x0167), "Lost Comm. Vehicle Immobilizer Control Module",
	UDTC(0x0168), "Lost Comm. Vehicle Security Control Module",
	UDTC(0x0169), "Lost Comm. Sunroof Control Module",
	UDTC(0x0170), "Lost Comm. 'Restraints System Sensor A'",
	UDTC(0x0171), "Lost Comm. 'Restraints System Sensor B'",
	UDTC(0x0172), "Lost Comm. 'Restraints System Sensor C'",
	UDTC(0x0173), "Lost Comm. 'Restraints System Sensor D'",
	UDTC(0x0174), "Lost Comm. 'Restraints System Sensor E'",
	UDTC(0x0175), "Lost Comm. 'Restraints System Sensor F'",
	UDTC(0x0176), "Lost Comm. 'Restraints System Sensor G'",
	UDTC(0x0177), "Lost Comm. 'Restraints System Sensor H'",
	UDTC(0x0178), "Lost Comm. 'Restraints System Sensor I'",
	UDTC(0x0179), "Lost Comm. 'Restraints System Sensor J'",
	UDTC(0x0180), "Lost Comm. Automatic Lighting Control Module",
	UDTC(0x0181), "Lost Comm. Headlamp Leveling Control Module",
	UDTC(0x0182), "Lost Comm. Lighting Control Module (Front)",
	UDTC(0x0183), "Lost Comm. Lighting Control Module (Rear)",
	UDTC(0x0184), "Lost Comm. with Radio",
	UDTC(0x0185), "Lost Comm. Ant. Control Module",
	UDTC(0x0186), "Lost Comm. Audio Amplifier",
	UDTC(0x0187), "Lost Comm. Digital Disc. Player Module 'A'",
	UDTC(0x0188), "Lost Comm. Digital Disc. Player Module 'B'",
	UDTC(0x0189), "Lost Comm. Digital Disc. Player Module 'C'",
	UDTC(0x0190), "Lost Comm. Digital Disc. Player Module 'D'",
	UDTC(0x0191), "Lost Comm. with Television",
	UDTC(0x0192), "Lost Comm. with Personal Computer",
	UDTC(0x0193), "Lost Comm. 'Digital Audio Control Module A'",
	UDTC(0x0194), "Lost Comm. 'Digital Audio Control Module B'",
	UDTC(0x0195), "Lost Comm. Subscription Ent. Receiver Module",
	UDTC(0x0196), "Lost Comm. Rear Seat Entertainment Control Module",
	UDTC(0x0197), "Lost Comm. Telephone Control Module",
	UDTC(0x0198), "Lost Comm. Telematic Control Module",
	UDTC(0x0199), "Lost Comm. 'Door Control Module A'",
	UDTC(0x0200), "Lost Comm. 'Door Control Module B'",
	UDTC(0x0201), "Lost Comm. 'Door Control Module C'",
	UDTC(0x0202), "Lost Comm. 'Door Control Module D'",
	UDTC(0x0203), "Lost Comm. 'Door Control Module E'",
	UDTC(0x0204), "Lost Comm. 'Door Control Module F'",
	UDTC(0x0205), "Lost Comm. 'Door Control Module G'",
	UDTC(0x0206), "Lost Comm. Folding Top Control Module",
	UDTC(0x0207), "Lost Comm. Moveable Roof Control Module",
	UDTC(0x0208), "Lost Comm. 'Seat Control Module A'",
	UDTC(0x0209), "Lost Comm. 'Seat Control Module B'",
	UDTC(0x0210), "Lost Comm. 'Seat Control Module C'",
	UDTC(0x0211), "Lost Comm. 'Seat Control Module D'",
	UDTC(0x0212), "Lost Comm. Steering Column Control Module",
	UDTC(0x0213), "Lost Comm. Mirror Control Module",
	UDTC(0x0214), "Lost Comm. Remote Function Actuation",
	UDTC(0x0215), "Lost Comm. 'Door Switch A'",
	UDTC(0x0216), "Lost Comm. 'Door Switch B'",
	UDTC(0x0217), "Lost Comm. 'Door Switch C'",
	UDTC(0x0218), "Lost Comm. 'Door Switch D'",
	UDTC(0x0219), "Lost Comm. 'Door Switch E'",
	UDTC(0x0220), "Lost Comm. 'Door Switch F'",
	UDTC(0x0221), "Lost Comm. 'Door Switch G'",
	UDTC(0x0222), "Lost Comm. 'Door Window Motor A'",
	UDTC(0x0223), "Lost Comm. 'Door Window Motor B'",
	UDTC(0x0224), "Lost Comm. 'Door Window Motor C'",
	UDTC(0x0225), "Lost Comm. 'Door Window Motor D'",
	UDTC(0x0226), "Lost Comm. 'Door Window Motor E'",
	UDTC(0x0227), "Lost Comm. 'Door Window Motor F'",
	UDTC(0x0228), "Lost Comm. 'Door Window Motor G'",
	UDTC(0x0229), "Lost Comm. Heated Steering Wheel Module",
	UDTC(0x0230), "Lost Comm. Rear Gate Module",
	UDTC(0x0231), "Lost Comm. Rain Sensing Module",
	UDTC(0x0232), "Lost Comm. Side Obstacle Detection Control Module (L)",
	UDTC(0x0233), "Lost Comm. Side Obstacle Detection Control Module (R)",
	UDTC(0x0234), "Lost Comm. Convenience Recall Module",
	UDTC(0x0235), "Lost Comm. Cruise Control Front Distance Range Sensor",
	UDTC(0x0300), "Internal Control Module Software Incompatibility",
	UDTC(0x0301), "Software Incompat. ECM/PCM",
	UDTC(0x0302), "Software Incompat. Transmission Control Module",
	UDTC(0x0303), "Software Incompat. Transfer Case Control Module",
	UDTC(0x0304), "Software Incompat. Gear Shift Control Module",
	UDTC(0x0305), "Software Incompat. Cruise Control Module",
	UDTC(0x0306), "Software Incompat. Fuel Injector Control Module",
	UDTC(0x0307), "Software Incompat. Glow Plug Control Module",
	UDTC(0x0308), "Software Incompat. Throttle Actuator Control Module",
	UDTC(0x0309), "Software Incompat. Alternative Fuel Control Module",
	UDTC(0x0310), "Software Incompat. Fuel Pump Control Module",
	UDTC(0x0311), "Software Incompat. Drive Motor Control Module",
	UDTC(0x0312), "Software Incompat. Battery Energy Control Module A",
	UDTC(0x0313), "Software Incompat. Battery Energy Control Module B",
	UDTC(0x0314), "Software Incompat. 4WD Clutch Control Module",
	UDTC(0x0315), "Software Incompat. Anti-Lock Brake System Control Module",
	UDTC(0x0316), "Software Incompat. Vehicle Dynamics Control Module",
	UDTC(0x0317), "Software Incompat. Park Brake Control Module",
	UDTC(0x0318), "Software Incompat. Brake System Control Module",
	UDTC(0x0319), "Software Incompat. Steering Effort Control Module",
	UDTC(0x0320), "Software Incompat. Power Steering Control Module",
	UDTC(0x0321), "Software Incompat. Ride Level Control Module",
	UDTC(0x0322), "Software Incompat. Body Control Module",
	UDTC(0x0323), "Software Incompat. Instrument Panel Control Module",
	UDTC(0x0324), "Software Incompat. HVAC Control Module",
	UDTC(0x0325), "Software Incompat. Auxiliary Heater Control Module",
	UDTC(0x0326), "Software Incompat. Vehicle Immobilizer Control Module",
	UDTC(0x0327), "Software Incompat. Vehicle Security Control Module",
	UDTC(0x0328), "Software Incompat. Steering Angle Sensor Module",
	UDTC(0x0329), "Software Incompat. Steering Column Control Module",
	UDTC(0x0330), "Software Incompat. Tire Pressure Monitor Module",
	UDTC(0x0331), "Software Incompat. Control Module",
	UDTC(0x0332), "Software Incompat. Body Control Module 'A'",
	UDTC(0x0400), "Invalid Data Received",
	UDTC(0x0401), "Invalid Data Rcvd. Transmission Control Module",
	UDTC(0x0402), "Invalid Data Rcvd. Transfer Case Control Module",
	UDTC(0x0403), "Invalid Data Rcvd. Gear Shift Control Module",
	UDTC(0x0404), "Invalid Data Rcvd. Cruise Control Module",
	UDTC(0x0405), "Invalid Data Rcvd. Fuel Injector Control Module",
	UDTC(0x0406), "Invalid Data Rcvd. Glow Plug Control Module",
	UDTC(0x0407), "Invalid Data Rcvd. Throttle Actuator Control Module",
	UDTC(0x0408), "Invalid Data Rcvd. Alternative Fuel Control Module",
	UDTC(0x0409), "Invalid Data Rcvd. Fuel Pump Control Module",
	UDTC(0x0410), "Invalid Data Rcvd. Drive Motor Control Module",
	UDTC(0x0411), "Invalid Data Rcvd. Battery Energy Control Module A",
	UDTC(0x0412), "Invalid Data Rcvd. Battery Energy Control Module B",
	UDTC(0x0413), "Invalid Data Rcvd. 4WD Clutch Control Module",
	UDTC(0x0414), "Invalid Data Rcvd. Anti-Lock Brake System Control Module",
	UDTC(0x0415), "Invalid Data Rcvd. Vehicle Dynamics Control Module",
	UDTC(0x0416), "Invalid Data Rcvd. Park Brake Control Module",
	UDTC(0x0417), "Invalid Data Rcvd. Brake System Control Module",
	UDTC(0x0418), "Invalid Data Rcvd. Steering Effort Control Module",
	UDTC(0x0419), "Invalid Data Rcvd. Power Steering Control Module",
	UDTC(0x0420), "Invalid Data Rcvd. Ride Level Control Module",
	UDTC(0x0421), "Invalid Data Rcvd. Body Control Module",
	UDTC(0x0422), "Invalid Data Rcvd. Instrument Panel Control Module",
	UDTC(0x0423), "Invalid Data Rcvd. HVAC Control Module",
	UDTC(0x0424), "Invalid Data Rcvd. Auxiliary Heater Control Module",
	UDTC(0x0425), "Invalid Data Rcvd. Vehicle Immobilizer Control Module",
	UDTC(0x0426), "Invalid Data Rcvd. Vehicle Security Control Module",
	UDTC(0x0427), "Invalid Data Rcvd. Steering Angle Sensor Module",
	UDTC(0x0428), "Invalid Data Rcvd. Steering Column Control Module",
	UDTC(0x0429), "Invalid Data Rcvd. Tire Pressure Monitor Module",
	UDTC(0x0430), "Invalid Data Rcvd. Control Module",
	UDTC(0x0431), "Invalid Data Rcvd. Body Control Module 'A'",
#endif
};

// Public API ................................................................

/*
	dtcFind
	
	See if a DTC is in the standard table
	
	Returns:  char *
*/

const char *
dtcFind(U16 dtc)
{
	U32 tsize;
	U32 l;
	tsize = sizeof(StandardDTCs) / sizeof(_DTC_INFO);

	// Try the table
	for (l=0 ; l<tsize ; l++)
	{
		if (StandardDTCs[l].DTC == dtc)
			return StandardDTCs[l].Description;
	}
	
	// Try some vendor specific ranges
	switch (dtc & 0xFF00)
	{
		case 0x1000:
		case 0x1100:
		case 0x1200:
			return "Make Specific (Fuel and Air Metering)";

		case 0x1300:
			return "Make Specific (Ignition System or Misfire)";

		case 0x1400:
			return "Make Specific (Aux. Emissions Controls)";

		case 0x1500:
			return "Make Specific (Speed, Idle Control, Aux Inputs)";

		case 0x1600:
			return "Make Specific (Computer and Aux. Outputs)";

		case 0x1700:
		case 0x1800:
		case 0x1900:
			return "Make Specific (Transmission)";
	}

	// OK, give up...
	return "No additional information available";	
}


/*
	dtcFormat
 
	Print a DTC into a standard string format
*/

void
dtcFormat(U16 dtc, char *outstr)
{
	U16 temp1, temp2;
	
	temp1 = dtc;
	temp2 = temp1 & 0xC000;
	temp1 &= 0x3FFF;
	if (! temp2)		
		sprintf(outstr, "P%04X", temp1);
	else if (temp2 == 0x4000)		
		sprintf(outstr, "C%04X", temp1);
	else if (temp2 == 0x8000)		
		sprintf(outstr, "B%04X", temp1);
	else
		sprintf(outstr, "U%04X", temp1);
}
